@@ -36,6 +36,7 @@
 #include <execinfo.h>
 #endif
 
+#include <errno.h>
 #include <fcntl.h>
 #include <signal.h>
 #include <stdlib.h>
@@ -43,7 +44,7 @@
 #include <stdio.h>
 #define WIN32_LEAN_AND_MEAN
 #define VC_EXTRALEAN
-#include <Winsock2.h>
+#include <ola/win/CleanWinSock2.h>
 #else
 #include <sys/resource.h>
 #endif
@@ -51,14 +52,128 @@
 
 #include <ola/ExportMap.h>
 #include <ola/Logging.h>
+#include <ola/StringUtils.h>
 #include <ola/base/Flags.h>
 #include <ola/base/Init.h>
 #include <ola/base/SysExits.h>
 #include <ola/math/Random.h>
+#include <ola/thread/Utils.h>
+#include <ola/system/Limits.h>
 
 #include <iostream>
 #include <string>
 
+// Scheduling options.
+DEFINE_string(scheduler_policy, "",
+              "The thread scheduling policy, one of {fifo, rr}.");
+DEFINE_uint16(scheduler_priority, 0,
+              "The thread priority, only used if --scheduler-policy is set.");
+
+namespace {
+
+using std::cout;
+using std::endl;
+using std::string;
+
+/*
+ * @private
+ * @brief Print a stack trace.
+ */
+static void _DumpStackAndExit(int sig) {
+#ifdef _WIN32
+  cout << "Received " << sig << endl;
+#else
+  cout << "Received " << strsignal(sig) << endl;
+#endif
+  #ifdef HAVE_EXECINFO_H
+  enum {STACK_SIZE = 64};
+  void *array[STACK_SIZE];
+  size_t size = backtrace(array, STACK_SIZE);
+
+  backtrace_symbols_fd(array, size, STDERR_FILENO);
+  #endif
+  exit(ola::EXIT_SOFTWARE);
+}
+
+bool SetThreadScheduling() {
+  string policy_str = FLAGS_scheduler_policy.str();
+  ola::ToLower(&policy_str);
+  if (policy_str.empty()) {
+    if (FLAGS_scheduler_priority.present()) {
+      OLA_WARN << "Must provide both of --scheduler-policy & "
+                  "--scheduler-priority";
+      return false;
+    }
+    return true;
+  }
+
+  int policy = 0;
+  if (policy_str == "fifo") {
+    policy = SCHED_FIFO;
+  } else if (policy_str == "rr") {
+    policy = SCHED_RR;
+  } else {
+    OLA_FATAL << "Unknown scheduling policy " << policy_str;
+    return false;
+  }
+
+  if (!FLAGS_scheduler_priority.present()) {
+    OLA_WARN << "Must provide both of --scheduler-policy & "
+                "--scheduler-priority";
+    return false;
+  }
+
+  int requested_priority = FLAGS_scheduler_priority;
+#ifdef _POSIX_PRIORITY_SCHEDULING
+  int min = sched_get_priority_min(policy);
+  int max = sched_get_priority_max(policy);
+
+  if (requested_priority < min) {
+    OLA_WARN << "Minimum value for --scheduler-priority is " << min;
+    return false;
+  }
+
+  if (requested_priority > max) {
+    OLA_WARN << "Maximum value for --scheduler-priority is " << max;
+    return false;
+  }
+#endif
+
+  // Set the scheduling parameters.
+  struct sched_param param;
+  param.sched_priority = requested_priority;
+
+  OLA_INFO << "Scheduling policy is " << ola::thread::PolicyToString(policy)
+           << ", priority " << param.sched_priority;
+  bool ok = ola::thread::SetSchedParam(pthread_self(), policy, param);
+  if (!ok) {
+    return false;
+  }
+
+  // If RLIMIT_RTTIME is available, set a bound on the length of uninterrupted
+  // CPU time we can consume.
+#if HAVE_DECL_RLIMIT_RTTIME
+  struct rlimit rlim;
+  if (!ola::system::GetRLimit(RLIMIT_RTTIME, &rlim)) {
+    return false;
+  }
+
+  // Cap CPU time at 1s.
+  rlim.rlim_cur = 1000000;
+  OLA_DEBUG << "Setting RLIMIT_RTTIME " << rlim.rlim_cur << " / "
+            << rlim.rlim_max;
+  if (!ola::system::SetRLimit(RLIMIT_RTTIME, rlim)) {
+    return false;
+  }
+
+  if (!ola::InstallSignal(SIGXCPU, _DumpStackAndExit)) {
+    return false;
+  }
+#endif
+  return true;
+}
+}  // namespace
+
 namespace ola {
 
 /**
@@ -70,23 +185,6 @@ using std::cout;
 using std::endl;
 using std::string;
 
-/**
- * @private
- * Print a stack trace on seg fault.
- */
-static void _SIGSEGV_Handler(int signal) {
-  cout << "Received SIGSEGV or SIGBUS" << endl;
-  #ifdef HAVE_EXECINFO_H
-  enum {STACK_SIZE = 64};
-  void *array[STACK_SIZE];
-  size_t size = backtrace(array, STACK_SIZE);
-
-  backtrace_symbols_fd(array, size, STDERR_FILENO);
-  #endif
-  exit(EXIT_SOFTWARE);
-  (void) signal;
-}
-
 bool ServerInit(int argc, char *argv[], ExportMap *export_map) {
   ola::math::InitRandom();
   if (!InstallSEGVHandler())
@@ -94,10 +192,9 @@ bool ServerInit(int argc, char *argv[], ExportMap *export_map) {
 
   if (export_map)
     InitExportMap(argc, argv, export_map);
-  return NetworkInit();
+  return SetThreadScheduling() && NetworkInit();
 }
 
-
 bool ServerInit(int *argc,
                 char *argv[],
                 ExportMap *export_map,
@@ -126,7 +223,7 @@ bool AppInit(int *argc,
   InitLoggingFromFlags();
   if (!InstallSEGVHandler())
     return false;
-  return NetworkInit();
+  return SetThreadScheduling() && NetworkInit();
 }
 
 #ifdef _WIN32
@@ -151,10 +248,10 @@ bool NetworkInit() {
 #endif
 }
 
-bool InstallSignal(int signal, void(*fp)(int signo)) {
+bool InstallSignal(int sig, void(*fp)(int signo)) {
 #ifdef _WIN32
-  if (::signal(signal, fp) == SIG_ERR) {
-    OLA_WARN << "Failed to install signal for " << signal;
+  if (::signal(sig, fp) == SIG_ERR) {
+    OLA_WARN << "signal(" << sig << ": " << strerror(errno);
     return false;
   }
 #else
@@ -163,24 +260,21 @@ bool InstallSignal(int signal, void(*fp)(int signo)) {
   sigemptyset(&action.sa_mask);
   action.sa_flags = 0;
 
-  if (sigaction(signal, &action, NULL) < 0) {
-    OLA_WARN << "Failed to install signal for " << signal;
+  if (sigaction(sig, &action, NULL) < 0) {
+    OLA_WARN << "sigaction(" << strsignal(sig) << ": " << strerror(errno);
     return false;
   }
 #endif  // _WIN32
   return true;
 }
 
-
 bool InstallSEGVHandler() {
 #ifndef _WIN32
-  if (!InstallSignal(SIGBUS, _SIGSEGV_Handler)) {
-    OLA_WARN << "Failed to install signal SIGBUS";
+  if (!InstallSignal(SIGBUS, _DumpStackAndExit)) {
     return false;
   }
 #endif  // !_WIN32
-  if (!InstallSignal(SIGSEGV, _SIGSEGV_Handler)) {
-    OLA_WARN << "Failed to install signal SIGSEGV";
+  if (!InstallSignal(SIGSEGV, _DumpStackAndExit)) {
     return false;
   }
   return true;
@@ -221,18 +315,14 @@ void InitExportMap(int argc, char* argv[], ExportMap *export_map) {
 
 void Daemonise() {
 #ifndef _WIN32
-  pid_t pid;
-  unsigned int i;
-  int fd0, fd1, fd2;
   struct rlimit rl;
-  struct sigaction sa;
-
   if (getrlimit(RLIMIT_NOFILE, &rl) < 0) {
     OLA_FATAL << "Could not determine file limit";
     exit(EXIT_OSFILE);
   }
 
-  // fork
+  // fork so we're not the process group leader
+  pid_t pid;
   if ((pid = fork()) < 0) {
     OLA_FATAL << "Could not fork\n";
     exit(EXIT_OSERR);
@@ -240,9 +330,11 @@ void Daemonise() {
     exit(EXIT_OK);
   }
 
-  // start a new session
+  // start a new session so we're the session leader and we free ourselves from
+  // the controlling terminal.
   setsid();
 
+  struct sigaction sa;
   sa.sa_handler = SIG_IGN;
   sigemptyset(&sa.sa_mask);
   sa.sa_flags = 0;
@@ -252,7 +344,8 @@ void Daemonise() {
     exit(EXIT_OSERR);
   }
 
-  if ((pid= fork()) < 0) {
+  // fork to ensure we're not the session leader.
+  if ((pid = fork()) < 0) {
     OLA_FATAL << "Could not fork\n";
     exit(EXIT_OSERR);
   } else if (pid != 0) {
@@ -266,19 +359,27 @@ void Daemonise() {
   }
 
   // close all fds
-  if (rl.rlim_max == RLIM_INFINITY)
-    rl.rlim_max = 1024;
-  for (i = 0; i < rl.rlim_max; i++)
-    close(i);
+  int maxfd = sysconf(_SC_OPEN_MAX);
+  if (maxfd == -1) {
+    if (rl.rlim_max == RLIM_INFINITY) {
+      maxfd = 1024;
+    } else {
+      maxfd = rl.rlim_max;
+    }
+  }
+
+  for (int fd = 0; fd < maxfd; fd++) {
+    close(fd);
+  }
 
   // send stdout, in and err to /dev/null
-  fd0 = open("/dev/null", O_RDWR);
-  fd1 = dup(0);
-  fd2 = dup(0);
+  int fd0 = open("/dev/null", O_RDWR);
+  int fd1 = dup(0);
+  int fd2 = dup(0);
 
-  if (fd0 != 0 || fd1 != 1 || fd2 != 2) {
-    OLA_FATAL << "Unexpected file descriptors: " << fd0 << ", " << fd1 << ", "
-      << fd2;
+  if (fd0 != STDIN_FILENO || fd1 != STDOUT_FILENO || fd2 != STDERR_FILENO) {
+    OLA_FATAL << "Unexpected file descriptors: " << fd0 << ", " << fd1
+              << ", " << fd2;
     exit(EXIT_OSERR);
   }
 #endif  // _WIN32
