@@ -419,9 +419,10 @@ ssize_t ConnectedDescriptor::Send(IOQueue *ioqueue) {
   return bytes_sent;
 }
 
-int ConnectedDescriptor::Receive(uint8_t *buffer,
-                                 unsigned int size,
-                                 unsigned int &data_read) { // NOLINT
+int ConnectedDescriptor::Receive(
+    uint8_t *buffer,
+    unsigned int size,
+    unsigned int &data_read) {  // NOLINT(runtime/references)
   int ret;
   uint8_t *data = buffer;
   data_read = 0;
