@@ -20,9 +20,10 @@
 
 #include "ola/io/IOUtils.h"
 
-#include <string.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <string.h>
+#include <sys/stat.h>
 #include <string>
 
 #include "ola/Logging.h"
@@ -35,10 +36,20 @@ using std::string;
 bool Open(const string &path, int oflag, int *fd) {
   *fd = open(path.c_str(), oflag);
   if (*fd < 0) {
-    OLA_WARN << "Failed to open " << path << ": " << strerror(errno);
+    OLA_WARN << "open(" << path << "): " << strerror(errno);
     return false;
   }
   return true;
 }
+
+bool TryOpen(const string &path, int oflag, int *fd) {
+  *fd = open(path.c_str(), oflag);
+  return *fd >= 0;
+}
+
+bool FileExists(const std::string &file_name) {
+  struct stat file_stat;
+  return 0 == stat(file_name.c_str(), &file_stat);
+}
 }  // namespace io
 }  // namespace ola
