@@ -28,7 +28,6 @@
 #include "ola/testing/TestUtils.h"
 
 using ola::io::MemoryBlock;
-using ola::testing::ASSERT_DATA_EQUALS;
 
 class MemoryBlockTest: public CppUnit::TestFixture {
  public:
@@ -66,8 +65,7 @@ void MemoryBlockTest::testAppend() {
   OLA_ASSERT_EQ(size - static_cast<unsigned int>(arraysize(data1)),
                 block.Remaining());
   OLA_ASSERT_FALSE(block.Empty());
-  ASSERT_DATA_EQUALS(__LINE__, data1, arraysize(data1),
-                     block.Data(), block.Size());
+  OLA_ASSERT_DATA_EQUALS(data1, arraysize(data1), block.Data(), block.Size());
 
   // pop 1 byte
   OLA_ASSERT_EQ(1u, block.PopFront(1));
@@ -75,8 +73,8 @@ void MemoryBlockTest::testAppend() {
   // popping doesn't change the location of the data in the memory block.
   OLA_ASSERT_EQ(96u, block.Remaining());
   OLA_ASSERT_FALSE(block.Empty());
-  ASSERT_DATA_EQUALS(__LINE__, data1 + 1, arraysize(data1) - 1,
-                     block.Data(), block.Size());
+  OLA_ASSERT_DATA_EQUALS(data1 + 1, arraysize(data1) - 1, block.Data(),
+                         block.Size());
 
   // try to pop more data than exists
   OLA_ASSERT_EQ(3u, block.PopFront(5));
@@ -105,8 +103,7 @@ void MemoryBlockTest::testPrepend() {
   OLA_ASSERT_EQ(4u, block.Size());
   OLA_ASSERT_EQ(0u, block.Remaining());
   OLA_ASSERT_FALSE(block.Empty());
-  ASSERT_DATA_EQUALS(__LINE__, data1, arraysize(data1),
-                     block.Data(), block.Size());
+  OLA_ASSERT_DATA_EQUALS(data1, arraysize(data1), block.Data(), block.Size());
 
   // pop
   OLA_ASSERT_EQ(1u, block.PopFront(1));
@@ -114,8 +111,8 @@ void MemoryBlockTest::testPrepend() {
   // popping doesn't change the location of the data in the memory block.
   OLA_ASSERT_EQ(0u, block.Remaining());
   OLA_ASSERT_FALSE(block.Empty());
-  ASSERT_DATA_EQUALS(__LINE__, data1 + 1, arraysize(data1) - 1,
-                     block.Data(), block.Size());
+  OLA_ASSERT_DATA_EQUALS(data1 + 1, arraysize(data1) - 1, block.Data(),
+                         block.Size());
 
   // try to pop more data than exists
   OLA_ASSERT_EQ(3u, block.PopFront(5));
