@@ -26,6 +26,7 @@
 #include <ola/base/Macro.h>
 #include <ola/io/Descriptor.h>
 
+#include <map>
 #include <set>
 
 #include "common/io/PollerInterface.h"
@@ -37,6 +38,7 @@ namespace io {
 /**
  * @class SelectPoller
  * @brief An implementation of PollerInterface that uses select().
+ *
  */
 class SelectPoller : public PollerInterface {
  public :
@@ -69,18 +71,9 @@ class SelectPoller : public PollerInterface {
     bool delete_on_close;
   } connected_descriptor_t;
 
-  struct connected_descriptor_t_lt {
-    bool operator()(const connected_descriptor_t &c1,
-                    const connected_descriptor_t &c2) const {
-      return c1.descriptor->ReadDescriptor() <
-          c2.descriptor->ReadDescriptor();
-    }
-  };
-
-  typedef std::set<ReadFileDescriptor*> ReadDescriptorSet;
-  typedef std::set<WriteFileDescriptor*> WriteDescriptorSet;
-  typedef std::set<connected_descriptor_t, connected_descriptor_t_lt>
-    ConnectedDescriptorSet;
+  typedef std::map<int, ReadFileDescriptor*> ReadDescriptorMap;
+  typedef std::map<int, WriteFileDescriptor*> WriteDescriptorMap;
+  typedef std::map<int, connected_descriptor_t*> ConnectedDescriptorMap;
 
   ExportMap *m_export_map;
   CounterVariable *m_loop_iterations;
@@ -88,9 +81,9 @@ class SelectPoller : public PollerInterface {
   Clock *m_clock;
   TimeStamp m_wake_up_time;
 
-  ReadDescriptorSet m_read_descriptors;
-  ConnectedDescriptorSet m_connected_read_descriptors;
-  WriteDescriptorSet m_write_descriptors;
+  ReadDescriptorMap m_read_descriptors;
+  WriteDescriptorMap m_write_descriptors;
+  ConnectedDescriptorMap m_connected_read_descriptors;
 
   void CheckDescriptors(fd_set *r_set, fd_set *w_set);
   bool AddDescriptorsToSet(fd_set *r_set, fd_set *w_set, int *max_sd);
