@@ -63,7 +63,7 @@ CPPUNIT_TEST_SUITE_REGISTRATION(InterfacePickerTest);
  */
 void InterfacePickerTest::testGetInterfaces() {
   auto_ptr<InterfacePicker> picker(InterfacePicker::NewPicker());
-  vector<Interface> interfaces = picker->GetInterfaces(false);
+  vector<Interface> interfaces = picker->GetInterfaces(true);
   OLA_ASSERT_TRUE(interfaces.size() > 0);
 
   vector<Interface>::iterator iter;
@@ -109,10 +109,13 @@ void InterfacePickerTest::testChooseInterface() {
   // no interfaces
   Interface iface;
   OLA_ASSERT_FALSE(picker.ChooseInterface(&iface, ""));
+  // no interfaces, by index
+  OLA_ASSERT_FALSE(picker.ChooseInterface(&iface, 0));
 
   // now with one iface that doesn't match
   Interface iface1;
   iface1.name = "eth0";
+  iface1.index = 1;
   OLA_ASSERT_TRUE(IPV4Address::FromString("10.0.0.1", &iface1.ip_address));
   interfaces.push_back(iface1);
 
@@ -123,6 +126,7 @@ void InterfacePickerTest::testChooseInterface() {
   // check that preferred works
   Interface iface2;
   iface2.name = "eth1";
+  iface2.index = 2;
   OLA_ASSERT_TRUE(IPV4Address::FromString("192.168.1.1", &iface2.ip_address));
   interfaces.push_back(iface2);
 
@@ -140,4 +144,12 @@ void InterfacePickerTest::testChooseInterface() {
   // a invalid address should return the first one
   OLA_ASSERT_TRUE(picker3.ChooseInterface(&iface, "foo"));
   OLA_ASSERT_TRUE(iface1 == iface);
+
+  // now check by iface index
+  OLA_ASSERT_TRUE(picker3.ChooseInterface(&iface, 2));
+  OLA_ASSERT_TRUE(iface2 == iface);
+
+  // an invalid index should return the first one
+  OLA_ASSERT_TRUE(picker3.ChooseInterface(&iface, 3));
+  OLA_ASSERT_TRUE(iface1 == iface);
 }
