@@ -11,13 +11,24 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * SocketAddressTest.cpp
  * Test fixture for the SocketAddress class
  * Copyright (C) 2012 Simon Newton
  */
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#ifdef HAVE_ARPA_INET_H
+#include <arpa/inet.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>  // Required by FreeBSD
+#endif
+
 #include <cppunit/extensions/HelperMacros.h>
 #include <string>
 
@@ -65,7 +76,7 @@ void SocketAddressTest::testIPV4SocketAddress() {
     reinterpret_cast<struct sockaddr_in*>(&sock_addr);
   OLA_ASSERT_EQ(ola::network::HostToNetwork(static_cast<uint16_t>(8080)),
                 sock_addr_in->sin_port);
-  IPV4Address actual_ip(sock_addr_in->sin_addr);
+  IPV4Address actual_ip(sock_addr_in->sin_addr.s_addr);
   OLA_ASSERT_EQ(ip_address, actual_ip);
 
   // test comparison operators
@@ -81,8 +92,13 @@ void SocketAddressTest::testIPV4SocketAddress() {
 
   OLA_ASSERT_LT(socket_address2, socket_address);
   OLA_ASSERT_LT(socket_address, socket_address3);
-  OLA_ASSERT_LT(socket_address, socket_address4);
-  OLA_ASSERT_LT(socket_address3, socket_address4);
+  OLA_ASSERT_LT(socket_address4, socket_address);
+  OLA_ASSERT_LT(socket_address4, socket_address3);
+
+  OLA_ASSERT_GT(socket_address, socket_address2);
+  OLA_ASSERT_GT(socket_address3, socket_address);
+  OLA_ASSERT_GT(socket_address, socket_address4);
+  OLA_ASSERT_GT(socket_address3, socket_address4);
 
   // test assignment & copy constructor
   IPV4SocketAddress copy_address(socket_address);
