@@ -178,35 +178,35 @@ SensorResponder::~SensorResponder() {
 /*
  * Handle an RDM Request
  */
-void SensorResponder::SendRDMRequest(const RDMRequest *request,
-                                          RDMCallback *callback) {
+void SensorResponder::SendRDMRequest(RDMRequest *request,
+                                     RDMCallback *callback) {
   RDMOps::Instance()->HandleRDMRequest(this, m_uid, ROOT_RDM_DEVICE, request,
                                        callback);
 }
 
-const RDMResponse *SensorResponder::GetDeviceInfo(
+RDMResponse *SensorResponder::GetDeviceInfo(
     const RDMRequest *request) {
   return ResponderHelper::GetDeviceInfo(
       request, OLA_SENSOR_ONLY_MODEL, PRODUCT_CATEGORY_TEST,
       2, 0, 1, 1, ZERO_FOOTPRINT_DMX_ADDRESS, 0, m_sensors.size());
 }
 
-const RDMResponse *SensorResponder::GetProductDetailList(
+RDMResponse *SensorResponder::GetProductDetailList(
     const RDMRequest *request) {
   // Shortcut for only one item in the vector
   return ResponderHelper::GetProductDetailList(
       request, vector<rdm_product_detail>(1, PRODUCT_DETAIL_TEST));
 }
 
-const RDMResponse *SensorResponder::GetIdentify(
+RDMResponse *SensorResponder::GetIdentify(
     const RDMRequest *request) {
   return ResponderHelper::GetBoolValue(request, m_identify_mode);
 }
 
-const RDMResponse *SensorResponder::SetIdentify(
+RDMResponse *SensorResponder::SetIdentify(
     const RDMRequest *request) {
   bool old_value = m_identify_mode;
-  const RDMResponse *response = ResponderHelper::SetBoolValue(
+  RDMResponse *response = ResponderHelper::SetBoolValue(
       request, &m_identify_mode);
   if (m_identify_mode != old_value) {
     OLA_INFO << "Sensor Device " << m_uid << ", identify mode "
@@ -215,22 +215,22 @@ const RDMResponse *SensorResponder::SetIdentify(
   return response;
 }
 
-const RDMResponse *SensorResponder::GetDeviceModelDescription(
+RDMResponse *SensorResponder::GetDeviceModelDescription(
     const RDMRequest *request) {
   return ResponderHelper::GetString(request, "OLA Sensor Device");
 }
 
-const RDMResponse *SensorResponder::GetManufacturerLabel(
+RDMResponse *SensorResponder::GetManufacturerLabel(
     const RDMRequest *request) {
   return ResponderHelper::GetString(request, OLA_MANUFACTURER_LABEL);
 }
 
-const RDMResponse *SensorResponder::GetDeviceLabel(
+RDMResponse *SensorResponder::GetDeviceLabel(
     const RDMRequest *request) {
   return ResponderHelper::GetString(request, "Sensor Device");
 }
 
-const RDMResponse *SensorResponder::GetSoftwareVersionLabel(
+RDMResponse *SensorResponder::GetSoftwareVersionLabel(
     const RDMRequest *request) {
   return ResponderHelper::GetString(request, string("OLA Version ") + VERSION);
 }
@@ -238,7 +238,7 @@ const RDMResponse *SensorResponder::GetSoftwareVersionLabel(
 /**
  * PID_SENSOR_DEFINITION
  */
-const RDMResponse *SensorResponder::GetSensorDefinition(
+RDMResponse *SensorResponder::GetSensorDefinition(
     const RDMRequest *request) {
   return ResponderHelper::GetSensorDefinition(request, m_sensors);
 }
@@ -246,18 +246,18 @@ const RDMResponse *SensorResponder::GetSensorDefinition(
 /**
  * PID_SENSOR_VALUE
  */
-const RDMResponse *SensorResponder::GetSensorValue(const RDMRequest *request) {
+RDMResponse *SensorResponder::GetSensorValue(const RDMRequest *request) {
   return ResponderHelper::GetSensorValue(request, m_sensors);
 }
 
-const RDMResponse *SensorResponder::SetSensorValue(const RDMRequest *request) {
+RDMResponse *SensorResponder::SetSensorValue(const RDMRequest *request) {
   return ResponderHelper::SetSensorValue(request, m_sensors);
 }
 
 /**
  * PID_RECORD_SENSORS
  */
-const RDMResponse *SensorResponder::RecordSensor(const RDMRequest *request) {
+RDMResponse *SensorResponder::RecordSensor(const RDMRequest *request) {
   return ResponderHelper::RecordSensor(request, m_sensors);
 }
 }  // namespace rdm
