@@ -18,22 +18,60 @@
  * Copyright (C) 2012 Simon Newton
  */
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <cppunit/CompilerOutputter.h>
 #include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/ui/text/TestRunner.h>
+#include <string>
+
+#include "ola/base/Env.h"
+#include "ola/base/Flags.h"
+#include "ola/base/Init.h"
 #include "ola/Logging.h"
+#include "ola/StringUtils.h"
+
+using std::string;
+
+#ifdef HAVE_EPOLL
+DECLARE_bool(use_epoll);
+#endif
+
+#ifdef HAVE_KQUEUE
+DECLARE_bool(use_kqueue);
+#endif
+
+DECLARE_uint8(log_level);
+
+bool GetBoolEnvVar(const string &var_name) {
+  string var;
+  bool result = false;
+  ola::GetEnv(var_name, &var) && ola::StringToBool(var, &result);
+  return result;
+}
 
 int main(int argc, char* argv[]) {
+  // Default to INFO since it's tests.
+  FLAGS_log_level = ola::OLA_LOG_INFO;
+
+#ifdef HAVE_EPOLL
+  FLAGS_use_epoll = GetBoolEnvVar("OLA_USE_EPOLL");
+#endif
+
+#ifdef HAVE_KQUEUE
+  FLAGS_use_kqueue = GetBoolEnvVar("OLA_USE_KQUEUE");
+#endif
+
+  ola::AppInit(&argc, argv, "[options]", "");
+
   CppUnit::Test *suite = CppUnit::TestFactoryRegistry::getRegistry().makeTest();
   CppUnit::TextUi::TestRunner runner;
   runner.addTest(suite);
-  // Enable logging.
-  ola::InitLogging(ola::OLA_LOG_INFO, ola::OLA_LOG_STDERR);
 
   runner.setOutputter(
       new CppUnit::CompilerOutputter(&runner.result(), std::cerr));
   bool wasSucessful = runner.run();
   return wasSucessful ? 0 : 1;
-  (void) argc;
-  (void) argv;
 }
