@@ -27,16 +27,15 @@
 #include "ola/StringUtils.h"
 #include "ola/testing/TestUtils.h"
 
-
 using ola::CapitalizeLabel;
 using ola::CustomCapitalizeLabel;
+using ola::EncodeString;
 using ola::Escape;
 using ola::EscapeString;
-using ola::EncodeString;
 using ola::FormatData;
 using ola::HexStringToInt;
-using ola::IntToString;
 using ola::IntToHexString;
+using ola::IntToString;
 using ola::PrefixedHexStringToInt;
 using ola::ReplaceAll;
 using ola::ShortenString;
@@ -47,11 +46,14 @@ using ola::StringSplit;
 using ola::StringToBool;
 using ola::StringToBoolTolerant;
 using ola::StringToInt;
+using ola::StringToIntOrDefault;
 using ola::StringTrim;
 using ola::StripPrefix;
 using ola::StripSuffix;
 using ola::ToLower;
 using ola::ToUpper;
+using ola::strings::ToHex;
+using std::ostringstream;
 using std::string;
 using std::vector;
 
@@ -71,11 +73,17 @@ class StringUtilsTest: public CppUnit::TestFixture {
   CPPUNIT_TEST(testStringToBool);
   CPPUNIT_TEST(testStringToBoolTolerant);
   CPPUNIT_TEST(testStringToUInt);
+  CPPUNIT_TEST(testStringToUIntOrDefault);
   CPPUNIT_TEST(testStringToUInt16);
+  CPPUNIT_TEST(testStringToUInt16OrDefault);
   CPPUNIT_TEST(testStringToUInt8);
+  CPPUNIT_TEST(testStringToUInt8OrDefault);
   CPPUNIT_TEST(testStringToInt);
+  CPPUNIT_TEST(testStringToIntOrDefault);
   CPPUNIT_TEST(testStringToInt16);
+  CPPUNIT_TEST(testStringToInt16OrDefault);
   CPPUNIT_TEST(testStringToInt8);
+  CPPUNIT_TEST(testStringToInt8OrDefault);
   CPPUNIT_TEST(testHexStringToInt);
   CPPUNIT_TEST(testPrefixedHexStringToInt);
   CPPUNIT_TEST(testToLower);
@@ -102,11 +110,17 @@ class StringUtilsTest: public CppUnit::TestFixture {
     void testStringToBool();
     void testStringToBoolTolerant();
     void testStringToUInt();
+    void testStringToUIntOrDefault();
     void testStringToUInt16();
+    void testStringToUInt16OrDefault();
     void testStringToUInt8();
+    void testStringToUInt8OrDefault();
     void testStringToInt();
+    void testStringToIntOrDefault();
     void testStringToInt16();
+    void testStringToInt16OrDefault();
     void testStringToInt8();
+    void testStringToInt8OrDefault();
     void testHexStringToInt();
     void testPrefixedHexStringToInt();
     void testToLower();
@@ -127,13 +141,13 @@ CPPUNIT_TEST_SUITE_REGISTRATION(StringUtilsTest);
 void StringUtilsTest::testSplit() {
   vector<string> tokens;
   string input = "";
-  StringSplit(input, tokens);
+  StringSplit(input, &tokens);
   OLA_ASSERT_EQ((size_t) 1, tokens.size());
   OLA_ASSERT_EQ(string(""), tokens[0]);
 
   input = "1 2 345";
   tokens.clear();
-  StringSplit(input, tokens);
+  StringSplit(input, &tokens);
 
   OLA_ASSERT_EQ((size_t) 3, tokens.size());
   OLA_ASSERT_EQ(string("1"), tokens[0]);
@@ -142,7 +156,7 @@ void StringUtilsTest::testSplit() {
 
   input = "1,2,345";
   tokens.clear();
-  StringSplit(input, tokens, ",");
+  StringSplit(input, &tokens, ",");
 
   OLA_ASSERT_EQ((size_t) 3, tokens.size());
   OLA_ASSERT_EQ(string("1"), tokens[0]);
@@ -151,7 +165,7 @@ void StringUtilsTest::testSplit() {
 
   input = ",1,2,345,,";
   tokens.clear();
-  StringSplit(input, tokens, ",");
+  StringSplit(input, &tokens, ",");
 
   OLA_ASSERT_EQ((size_t) 6, tokens.size());
   OLA_ASSERT_EQ(string(""), tokens[0]);
@@ -163,7 +177,7 @@ void StringUtilsTest::testSplit() {
 
   input = "1 2,345";
   tokens.clear();
-  StringSplit(input, tokens, " ,");
+  StringSplit(input, &tokens, " ,");
 
   OLA_ASSERT_EQ((size_t) 3, tokens.size());
   OLA_ASSERT_EQ(string("1"), tokens[0]);
@@ -172,7 +186,7 @@ void StringUtilsTest::testSplit() {
 
   input = "1, 2,345";
   tokens.clear();
-  StringSplit(input, tokens, " ,");
+  StringSplit(input, &tokens, " ,");
 
   OLA_ASSERT_EQ((size_t) 4, tokens.size());
   OLA_ASSERT_EQ(string("1"), tokens[0]);
@@ -182,10 +196,23 @@ void StringUtilsTest::testSplit() {
 
   input = "1";
   tokens.clear();
-  StringSplit(input, tokens, ".");
+  StringSplit(input, &tokens, ".");
 
   OLA_ASSERT_EQ((size_t) 1, tokens.size());
   OLA_ASSERT_EQ(string("1"), tokens[0]);
+
+  // And the old non-pointer version
+  input = ",1,2,345,,";
+  tokens.clear();
+  StringSplit(input, tokens, ",");
+
+  OLA_ASSERT_EQ((size_t) 6, tokens.size());
+  OLA_ASSERT_EQ(string(""), tokens[0]);
+  OLA_ASSERT_EQ(string("1"), tokens[1]);
+  OLA_ASSERT_EQ(string("2"), tokens[2]);
+  OLA_ASSERT_EQ(string("345"), tokens[3]);
+  OLA_ASSERT_EQ(string(""), tokens[4]);
+  OLA_ASSERT_EQ(string(""), tokens[5]);
 }
 
 
@@ -313,6 +340,7 @@ void StringUtilsTest::testIntToString() {
  * test the IntToHexString function.
  */
 void StringUtilsTest::testIntToHexString() {
+  // Using the old IntToHexString
   OLA_ASSERT_EQ(string("0x00"), IntToHexString((uint8_t)0));
 
   OLA_ASSERT_EQ(string("0x01"), IntToHexString((uint8_t)1));
@@ -323,6 +351,45 @@ void StringUtilsTest::testIntToHexString() {
 
   unsigned int i = 0x42;
   OLA_ASSERT_EQ(string("0x00000042"), IntToHexString(i));
+
+  // Using the inline string concatenation
+  ostringstream str;
+  str << ToHex((uint8_t)0);
+  OLA_ASSERT_EQ(string("0x00"), str.str());
+  str.str("");
+
+  str << ToHex((uint8_t)1);
+  OLA_ASSERT_EQ(string("0x01"), str.str());
+  str.str("");
+
+  str << ToHex((uint8_t)0x42);
+  OLA_ASSERT_EQ(string("0x42"), str.str());
+  str.str("");
+
+  str << ToHex((uint16_t)0x0001);
+  OLA_ASSERT_EQ(string("0x0001"), str.str());
+  str.str("");
+
+  str << ToHex((uint16_t)0xABCD);
+  OLA_ASSERT_EQ(string("0xabcd"), str.str());
+  str.str("");
+
+  str << ToHex((uint32_t)0xDEADBEEF);
+  OLA_ASSERT_EQ(string("0xdeadbeef"), str.str());
+  str.str("");
+
+  str << ToHex(i);
+  OLA_ASSERT_EQ(string("0x00000042"), str.str());
+  str.str("");
+
+  // Without prefix
+  str << ToHex((uint8_t)0x42, false);
+  OLA_ASSERT_EQ(string("42"), str.str());
+  str.str("");
+
+  str << ToHex((uint16_t)0xABCD, false);
+  OLA_ASSERT_EQ(string("abcd"), str.str());
+  str.str("");
 }
 
 
@@ -491,6 +558,23 @@ void StringUtilsTest::testStringToUInt() {
   OLA_ASSERT_FALSE(StringToInt("4294967295bat bar", &value, true));
 }
 
+void StringUtilsTest::testStringToUIntOrDefault() {
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("", 42u));
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("-1", 42u));
+  OLA_ASSERT_EQ(0u, StringToIntOrDefault("0", 42u));
+  OLA_ASSERT_EQ(1u, StringToIntOrDefault("1", 42u));
+  OLA_ASSERT_EQ(65537u, StringToIntOrDefault("65537", 42u));
+  OLA_ASSERT_EQ(4294967295U, StringToIntOrDefault("4294967295", 42u));
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("4294967296", 42u));
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("foo", 42u));
+
+  // same tests with strict mode on
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("-1 foo", 42u, true));
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("0 ", 42u, true));
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("1 bar baz", 42u, true));
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("65537cat", 42u, true));
+  OLA_ASSERT_EQ(42u, StringToIntOrDefault("4294967295bat bar", 42u, true));
+}
 
 void StringUtilsTest::testHexStringToInt() {
   unsigned int value;
@@ -697,6 +781,18 @@ void StringUtilsTest::testStringToUInt16() {
 }
 
 
+void StringUtilsTest::testStringToUInt16OrDefault() {
+  OLA_ASSERT_EQ((uint16_t) 42, StringToIntOrDefault("", (uint16_t) 42));
+  OLA_ASSERT_EQ((uint16_t) 42, StringToIntOrDefault("-1", (uint16_t) 42));
+  OLA_ASSERT_EQ((uint16_t) 42, StringToIntOrDefault("65536", (uint16_t) 42));
+
+  OLA_ASSERT_EQ((uint16_t) 0, StringToIntOrDefault("0", (uint16_t) 42));
+  OLA_ASSERT_EQ((uint16_t) 1, StringToIntOrDefault("1", (uint16_t) 42));
+  OLA_ASSERT_EQ((uint16_t) 143, StringToIntOrDefault("143", (uint16_t) 42));
+  OLA_ASSERT_EQ((uint16_t) 65535, StringToIntOrDefault("65535", (uint16_t) 42));
+}
+
+
 void StringUtilsTest::testStringToUInt8() {
   uint8_t value;
 
@@ -715,6 +811,18 @@ void StringUtilsTest::testStringToUInt8() {
 }
 
 
+void StringUtilsTest::testStringToUInt8OrDefault() {
+  OLA_ASSERT_EQ((uint8_t) 42, StringToIntOrDefault("", (uint8_t) 42));
+  OLA_ASSERT_EQ((uint8_t) 42, StringToIntOrDefault("-1", (uint8_t) 42));
+  OLA_ASSERT_EQ((uint8_t) 42, StringToIntOrDefault("256", (uint8_t) 42));
+
+  OLA_ASSERT_EQ((uint8_t) 0, StringToIntOrDefault("0", (uint8_t) 42));
+  OLA_ASSERT_EQ((uint8_t) 1, StringToIntOrDefault("1", (uint8_t) 42));
+  OLA_ASSERT_EQ((uint8_t) 143, StringToIntOrDefault("143", (uint8_t) 42));
+  OLA_ASSERT_EQ((uint8_t) 255, StringToIntOrDefault("255", (uint8_t) 42));
+}
+
+
 void StringUtilsTest::testStringToInt() {
   int value;
   OLA_ASSERT_FALSE(StringToInt("", &value));
@@ -751,6 +859,35 @@ void StringUtilsTest::testStringToInt() {
 }
 
 
+void StringUtilsTest::testStringToIntOrDefault() {
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("", 42));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("a", 42));
+
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("2147483649", 42));
+  OLA_ASSERT_EQ(static_cast<int>(-2147483647 - 1),
+                StringToIntOrDefault("-2147483648", 42));
+  OLA_ASSERT_EQ(-2147483647, StringToIntOrDefault("-2147483647", 42));
+  OLA_ASSERT_EQ(-1, StringToIntOrDefault("-1", 42));
+
+  OLA_ASSERT_EQ(0, StringToIntOrDefault("0", 42));
+  OLA_ASSERT_EQ(1, StringToIntOrDefault("1", 42));
+  OLA_ASSERT_EQ(143, StringToIntOrDefault("143", 42));
+  OLA_ASSERT_EQ(2147483647, StringToIntOrDefault("2147483647", 42));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("2147483648", 42));
+
+  // strict mode on
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("2147483649 ", 42, true));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("-2147483648bar", 42, true));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("-2147483647 baz", 42, true));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("-1.", 42, true));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("0!", 42, true));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("1 this is a test", 42, true));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("143car", 42, true));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("2147483647 !@#", 42, true));
+  OLA_ASSERT_EQ(42, StringToIntOrDefault("2147483648mm", 42, true));
+}
+
+
 void StringUtilsTest::testStringToInt16() {
   int16_t value;
 
@@ -777,6 +914,23 @@ void StringUtilsTest::testStringToInt16() {
 }
 
 
+void StringUtilsTest::testStringToInt16OrDefault() {
+  OLA_ASSERT_EQ((int16_t) 42, StringToIntOrDefault("", (int16_t) 42));
+  OLA_ASSERT_EQ((int16_t) 42, StringToIntOrDefault("a", (int16_t) 42));
+
+  OLA_ASSERT_EQ((int16_t) 42, StringToIntOrDefault("-32769", (int16_t) 42));
+  OLA_ASSERT_EQ((int16_t) -32768, StringToIntOrDefault("-32768", (int16_t) 42));
+  OLA_ASSERT_EQ((int16_t) -32767, StringToIntOrDefault("-32767", (int16_t) 42));
+  OLA_ASSERT_EQ((int16_t) -1, StringToIntOrDefault("-1", (int16_t) 42));
+
+  OLA_ASSERT_EQ((int16_t) 0, StringToIntOrDefault("0", (int16_t) 42));
+  OLA_ASSERT_EQ((int16_t) 1, StringToIntOrDefault("1", (int16_t) 42));
+  OLA_ASSERT_EQ((int16_t) 143, StringToIntOrDefault("143", (int16_t) 42));
+  OLA_ASSERT_EQ((int16_t) 32767, StringToIntOrDefault("32767", (int16_t) 42));
+  OLA_ASSERT_EQ((int16_t) 42, StringToIntOrDefault("32768", (int16_t) 42));
+}
+
+
 void StringUtilsTest::testStringToInt8() {
   int8_t value;
 
@@ -803,6 +957,23 @@ void StringUtilsTest::testStringToInt8() {
 }
 
 
+void StringUtilsTest::testStringToInt8OrDefault() {
+  OLA_ASSERT_EQ((int8_t) 42, StringToIntOrDefault("", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) 42, StringToIntOrDefault("a", (int8_t) 42));
+
+  OLA_ASSERT_EQ((int8_t) 42, StringToIntOrDefault("-129", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) -128, StringToIntOrDefault("-128", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) -127, StringToIntOrDefault("-127", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) -127, StringToIntOrDefault("-127", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) -1, StringToIntOrDefault("-1", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) 0, StringToIntOrDefault("0", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) 1, StringToIntOrDefault("1", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) 127, StringToIntOrDefault("127", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) 42, StringToIntOrDefault("128", (int8_t) 42));
+  OLA_ASSERT_EQ((int8_t) 42, StringToIntOrDefault("129", (int8_t) 42));
+}
+
+
 void StringUtilsTest::testToLower() {
   string s = "HelLo There";
   ToLower(&s);
@@ -901,6 +1072,12 @@ void StringUtilsTest::testStringJoin() {
   ints.push_back(3);
   OLA_ASSERT_EQ(string("1,2,3"), StringJoin(",", ints));
 
+  vector<char> chars;
+  chars.push_back('a');
+  chars.push_back('b');
+  chars.push_back('c');
+  OLA_ASSERT_EQ(string("a,b,c"), StringJoin(",", chars));
+
   vector<string> strings;
   strings.push_back("one");
   strings.push_back("two");
