@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * TokenBucketTest.cpp
  * Test fixture for the TokenBucket class
@@ -42,10 +42,6 @@ class TokenBucketTest: public CppUnit::TestFixture {
  public:
     void testTokenBucket();
     void testTokenBucketTwo();
-
-    void setUp() {
-      ola::InitLogging(ola::OLA_LOG_INFO, ola::OLA_LOG_STDERR);
-    }
 };
 
 
