@@ -43,20 +43,26 @@
 #include <sys/timeb.h>
 #endif
 #include <ola/Callback.h>
+#include <ola/Clock.h>
 #include <ola/Constants.h>
-#include <ola/OlaCallbackClient.h>
-#include <ola/OlaClientWrapper.h>
 #include <ola/DmxBuffer.h>
 #include <ola/base/Init.h>
+#include <ola/base/Macro.h>
 #include <ola/base/SysExits.h>
+#include <ola/client/ClientWrapper.h>
+#include <ola/client/OlaClient.h>
 #include <ola/io/SelectServer.h>
 
 #include <string>
 #include <iostream>
 
+using ola::Clock;
 using ola::DmxBuffer;
-using ola::OlaCallbackClient;
-using ola::OlaCallbackClientWrapper;
+using ola::client::OlaClient;
+using ola::client::OlaClientWrapper;
+using ola::client::Result;
+using ola::TimeInterval;
+using ola::TimeStamp;
 using ola::io::SelectServer;
 using std::string;
 
@@ -125,10 +131,9 @@ class DmxMonitor {
 
     bool Init();
     void Run() { m_client.GetSelectServer()->Run(); }
-    void NewDmx(unsigned int universe,
-                const DmxBuffer &buffer,
-                const string &error);
-    void RegisterComplete(const string &error);
+    void NewDmx(const ola::client::DMXMetadata &meta,
+                const DmxBuffer &buffer);
+    void RegisterComplete(const Result &result);
     void StdinReady();
     bool CheckDataLoss();
     void DrawDataLossWindow();
@@ -139,11 +144,11 @@ class DmxMonitor {
     unsigned int m_counter;
     int m_palette_number;
     ola::io::UnmanagedFileDescriptor m_stdin_descriptor;
-    struct timeval m_last_data;
+    TimeStamp m_last_data;
     WINDOW *m_window;
     WINDOW *m_data_loss_window;
     bool m_channels_offset;  // start from channel 1 rather than 0;
-    OlaCallbackClientWrapper m_client;
+    OlaClientWrapper m_client;
     DmxBuffer m_buffer;
 
     void DrawScreen(bool include_values = true);
@@ -164,11 +169,11 @@ bool DmxMonitor::Init() {
     return false;
   }
 
-  OlaCallbackClient *client = m_client.GetClient();
-  client->SetDmxCallback(ola::NewCallback(this, &DmxMonitor::NewDmx));
+  OlaClient *client = m_client.GetClient();
+  client->SetDMXCallback(ola::NewCallback(this, &DmxMonitor::NewDmx));
   client->RegisterUniverse(
       m_universe,
-      ola::REGISTER,
+      ola::client::REGISTER,
       ola::NewSingleCallback(this, &DmxMonitor::RegisterComplete));
 
   /* init curses */
@@ -194,7 +199,6 @@ bool DmxMonitor::Init() {
   ChangePalette(m_palette_number);
 
   m_buffer.Blackout();
-  timerclear(&m_last_data);
   DrawScreen();
   return true;
 }
@@ -203,9 +207,8 @@ bool DmxMonitor::Init() {
 /*
  * Called when there is new DMX data
  */
-void DmxMonitor::NewDmx(unsigned int universe,
-                        const DmxBuffer &buffer,
-                        const string &error) {
+void DmxMonitor::NewDmx(OLA_UNUSED const ola::client::DMXMetadata &meta,
+                        const DmxBuffer &buffer) {
   m_buffer.Set(buffer);
 
   if (m_data_loss_window) {
@@ -232,17 +235,17 @@ void DmxMonitor::NewDmx(unsigned int universe,
       break;
   }
   m_counter++;
-  gettimeofday(&m_last_data, NULL);
+
+  Clock clock;
+  clock.CurrentTime(&m_last_data);
   Values();
   refresh();
-  (void) universe;
-  (void) error;
 }
 
 
-void DmxMonitor::RegisterComplete(const string &error) {
-  if (!error.empty()) {
-    std::cerr << "Register command failed with " << errno <<
+void DmxMonitor::RegisterComplete(const Result &result) {
+  if (!result.Success()) {
+    std::cerr << "Register command failed with " << result.Error() <<
       std::endl;
     m_client.GetSelectServer()->Terminate();
   }
@@ -359,12 +362,12 @@ void DmxMonitor::StdinReady() {
  * TODO(simon): move to the ola server
  */
 bool DmxMonitor::CheckDataLoss() {
-  struct timeval now, diff;
-
-  if (timerisset(&m_last_data)) {
-    gettimeofday(&now, NULL);
-    timersub(&now, &m_last_data, &diff);
-    if (diff.tv_sec > 2 || (diff.tv_sec == 2 && diff.tv_usec > 500000)) {
+  if (m_last_data.IsSet()) {
+    TimeStamp now;
+    Clock clock;
+    clock.CurrentTime(&now);
+    TimeInterval diff = now - m_last_data;
+    if (diff > TimeInterval(2, 5000000)) {
       // loss of data
       DrawDataLossWindow();
     }
@@ -559,6 +562,7 @@ void DmxMonitor::ChangePalette(int p) {
   switch (p) {
     default:
       m_palette_number = 0;
+      // fall through, use 0 as default palette
     case 0:
       init_pair(CHANNEL, COLOR_BLACK, COLOR_CYAN);
       init_pair(ZERO, COLOR_BLACK, COLOR_WHITE);
@@ -580,23 +584,23 @@ void DmxMonitor::ChangePalette(int p) {
       goto color;
 
     color:
-      palette[CHANNEL]=COLOR_PAIR(CHANNEL);
-      palette[ZERO]=COLOR_PAIR(ZERO);
-      palette[NORM]=COLOR_PAIR(NORM);
-      palette[FULL]=COLOR_PAIR(FULL);
-      palette[HEADLINE]=COLOR_PAIR(HEADLINE);
-      palette[HEADEMPH]=COLOR_PAIR(HEADEMPH);
-      palette[HEADERROR]=COLOR_PAIR(HEADERROR);
+      palette[CHANNEL] = COLOR_PAIR(CHANNEL);
+      palette[ZERO] = COLOR_PAIR(ZERO);
+      palette[NORM] = COLOR_PAIR(NORM);
+      palette[FULL] = COLOR_PAIR(FULL);
+      palette[HEADLINE] = COLOR_PAIR(HEADLINE);
+      palette[HEADEMPH] = COLOR_PAIR(HEADEMPH);
+      palette[HEADERROR] = COLOR_PAIR(HEADERROR);
       break;
 
     case 1:
-      palette[CHANNEL]=A_REVERSE;
-      palette[ZERO]=A_NORMAL;
-      palette[NORM]=A_NORMAL;
-      palette[FULL]=A_BOLD;
-      palette[HEADLINE]=A_NORMAL;
-      palette[HEADEMPH]=A_NORMAL;
-      palette[HEADERROR]=A_BOLD;
+      palette[CHANNEL] = A_REVERSE;
+      palette[ZERO] = A_NORMAL;
+      palette[NORM] = A_NORMAL;
+      palette[FULL] = A_BOLD;
+      palette[HEADLINE] = A_NORMAL;
+      palette[HEADEMPH] = A_NORMAL;
+      palette[HEADERROR] = A_BOLD;
       break;
     }
 }
