@@ -66,7 +66,7 @@ class UniverseTracker {
     void ResetStats();
 
  protected:
-    void Input(char c);
+    void Input(int c);
 
  private:
     struct UniverseStats {
@@ -175,7 +175,7 @@ void UniverseTracker::ResetStats() {
   cout << "Reset counters" << endl;
 }
 
-void UniverseTracker::Input(char c) {
+void UniverseTracker::Input(int c) {
   switch (c) {
     case 'q':
       m_wrapper->GetSelectServer()->Terminate();
@@ -234,10 +234,12 @@ void UniverseTracker::RegisterComplete(const string &error) {
 
 SelectServer *ss = NULL;
 
-static void InteruptSignal(int unused) {
-  if (ss)
+static void InteruptSignal(OLA_UNUSED int signo) {
+  int old_errno = errno;
+  if (ss) {
     ss->Terminate();
-  (void) unused;
+  }
+  errno = old_errno;
 }
 
 
