@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Credentials.h
  * Handle getting and setting a process's credentials.
@@ -36,6 +36,15 @@
 #include <unistd.h>
 #include <string>
 
+#ifdef _WIN32
+#ifndef uid_t
+#define uid_t int
+#endif
+#ifndef gid_t
+#define gid_t int
+#endif
+#endif
+
 namespace ola {
 
 /**
@@ -51,16 +60,24 @@ namespace ola {
  * */
 
 /**
- * @brief Get the real UID of the process.
- * @return real user id of the proccess
+ * @brief Check whether the current platform supports User and Group IDs.
+ * @return true on *nix, false on Windows
  */
-uid_t GetUID();
+bool SupportsUIDs();
+
+/**
+ * @brief Get the real UID of the process.
+ * @param uid is the variable to receive the real UID
+ * @return true on success, false otherwise
+ */
+bool GetUID(uid_t* uid);
 
 /**
  * @brief Get the effective UID of the process.
- * @return effective user id of the process
+ * @param euid is the variable to receive the effective UID
+ * @return true on success, false otherwise
  */
-uid_t GetEUID();
+bool GetEUID(uid_t* euid);
 
 /**
  * @brief Set the effective UID of the process.
@@ -80,15 +97,17 @@ bool SetUID(uid_t new_uid);
 
 /**
  * @brief Get the real Group ID
- * @return the real Group ID
+ * @param gid is the variable to receive the real Group ID
+ * @return true on success, false otherwise
  */
-gid_t GetGID();
+bool GetGID(gid_t* gid);
 
 /**
  * @brief Get the effective group ID
- * @return the effective Group ID
+ * @param egid is the variable to receive the effective Group ID
+ * @return true on success, false otherwise
  */
-gid_t GetEGID();
+bool GetEGID(gid_t* egid);
 
 /**
  * @brief Set the effective Group ID of the process
