@@ -210,6 +210,8 @@ class HTTPServer: public ola::thread::Thread {
   // Expose the SelectServer
   ola::io::SelectServer *SelectServer() { return m_select_server.get(); }
 
+  static struct MHD_Response *BuildResponse(void *data, size_t size);
+
  private :
   typedef struct {
     std::string file_path;
@@ -218,8 +220,8 @@ class HTTPServer: public ola::thread::Thread {
 
   struct DescriptorState {
    public:
-    explicit DescriptorState(ola::io::UnmanagedFileDescriptor *descriptor)
-        : descriptor(descriptor), read(0), write(0) {}
+    explicit DescriptorState(ola::io::UnmanagedFileDescriptor *_descriptor)
+        : descriptor(_descriptor), read(0), write(0) {}
 
     ola::io::UnmanagedFileDescriptor *descriptor;
     uint8_t read    : 1;
