@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * MessagePrinter.h
  * Print the contents of a message.
@@ -53,14 +53,14 @@ class MessagePrinter: public MessageVisitor {
     virtual void PostVisit(const GroupMessageField*) {}
 
  protected:
-    std::stringstream& Stream() { return m_str; }
+    std::ostringstream& Stream() { return m_str; }
     virtual void PostStringHook() {}
     virtual std::string TransformLabel(const std::string &label) {
       return label;
     }
 
  private:
-    std::stringstream m_str;
+    std::ostringstream m_str;
 };
 
 
