@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Socket.h
  * The Socket interfaces
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  *
  *  - UDPSocket, allows sending and receiving UDP datagrams
  *  - TCPSocket, this represents a TCP connection to a remote endpoint
@@ -30,54 +30,41 @@
 
 #include <stdint.h>
 
-#ifdef WIN32
-#include <winsock2.h>
-#include <ws2tcpip.h>
-#else
-#include <sys/socket.h>
-#include <netinet/in.h>
-#endif
-
+#include <ola/base/Macro.h>
 #include <ola/io/Descriptor.h>
 #include <ola/network/IPV4Address.h>
 #include <ola/network/SocketAddress.h>
 
-
 namespace ola {
 namespace network {
 
-
 /*
  * A TCPSocket
  */
 class TCPSocket: public ola::io::ConnectedDescriptor {
  public:
-    explicit TCPSocket(int sd)
-        : m_sd(sd) {
-      SetNoSigPipe(sd);
-    }
+  explicit TCPSocket(int sd);
 
-    ~TCPSocket() { Close(); }
+  ~TCPSocket() { Close(); }
 
-    int ReadDescriptor() const { return m_sd; }
-    int WriteDescriptor() const { return m_sd; }
-    bool Close();
+  ola::io::DescriptorHandle ReadDescriptor() const { return m_handle; }
+  ola::io::DescriptorHandle WriteDescriptor() const { return m_handle; }
+  bool Close();
 
-    GenericSocketAddress GetLocalAddress() const;
-    GenericSocketAddress GetPeerAddress() const;
+  GenericSocketAddress GetLocalAddress() const;
+  GenericSocketAddress GetPeerAddress() const;
 
-    static TCPSocket* Connect(const SocketAddress &endpoint);
+  static TCPSocket* Connect(const SocketAddress &endpoint);
 
-    bool SetNoDelay();
+  bool SetNoDelay();
 
  protected:
-    bool IsSocket() const { return true; }
+  bool IsSocket() const { return true; }
 
  private:
-    int m_sd;
+  ola::io::DescriptorHandle m_handle;
 
-    TCPSocket(const TCPSocket &other);
-    TCPSocket& operator=(const TCPSocket &other);
+  DISALLOW_COPY_AND_ASSIGN(TCPSocket);
 };
 
 
@@ -86,25 +73,24 @@ class TCPSocket: public ola::io::ConnectedDescriptor {
  */
 class TCPAcceptingSocket: public ola::io::ReadFileDescriptor {
  public:
-    explicit TCPAcceptingSocket(class TCPSocketFactoryInterface *factory);
-    ~TCPAcceptingSocket();
-    bool Listen(const SocketAddress &endpoint, int backlog = 10);
-    int ReadDescriptor() const { return m_sd; }
-    bool Close();
-    void PerformRead();
+  explicit TCPAcceptingSocket(class TCPSocketFactoryInterface *factory);
+  ~TCPAcceptingSocket();
+  bool Listen(const SocketAddress &endpoint, int backlog = 10);
+  ola::io::DescriptorHandle ReadDescriptor() const { return m_handle; }
+  bool Close();
+  void PerformRead();
 
-    void SetFactory(class TCPSocketFactoryInterface *factory) {
-      m_factory = factory;
-    }
+  void SetFactory(class TCPSocketFactoryInterface *factory) {
+    m_factory = factory;
+  }
 
-    GenericSocketAddress GetLocalAddress() const;
+  GenericSocketAddress GetLocalAddress() const;
 
  private:
-    int m_sd;
-    class TCPSocketFactoryInterface *m_factory;
+  ola::io::DescriptorHandle m_handle;
+  class TCPSocketFactoryInterface *m_factory;
 
-    TCPAcceptingSocket(const TCPAcceptingSocket &other);
-    TCPAcceptingSocket& operator=(const TCPAcceptingSocket &other);
+  DISALLOW_COPY_AND_ASSIGN(TCPAcceptingSocket);
 };
 }  // namespace network
 }  // namespace ola
