@@ -19,7 +19,7 @@
  *
  * This class provides a high level C++ RDM API for PIDs defined in
  * E1.20. It includes errors checking for out-of-range arguments. Each RDM
- * method takes a pointer to a string, which will be populated with an english
+ * method takes a pointer to a string, which will be populated with an English
  * error message if the command fails.
  */
 
@@ -892,6 +892,40 @@ class RDMAPI {
         ola::SingleUseCallback1<void, const ResponseStatus&> *callback,
         std::string *error);
 
+    bool GetDnsHostname(
+        unsigned int universe,
+        const UID &uid,
+        uint16_t sub_device,
+        ola::SingleUseCallback2<void,
+                                const ResponseStatus&,
+                                const std::string&> *callback,
+        std::string *error);
+
+    bool SetDnsHostname(
+        unsigned int universe,
+        const UID &uid,
+        uint16_t sub_device,
+        const std::string &label,
+        ola::SingleUseCallback1<void, const ResponseStatus&> *callback,
+        std::string *error);
+
+    bool GetDnsDomainName(
+        unsigned int universe,
+        const UID &uid,
+        uint16_t sub_device,
+        ola::SingleUseCallback2<void,
+                                const ResponseStatus&,
+                                const std::string&> *callback,
+        std::string *error);
+
+    bool SetDnsDomainName(
+        unsigned int universe,
+        const UID &uid,
+        uint16_t sub_device,
+        const std::string &label,
+        ola::SingleUseCallback1<void, const ResponseStatus&> *callback,
+        std::string *error);
+
     bool SelfTestEnabled(
         unsigned int universe,
         const UID &uid,
@@ -951,6 +985,14 @@ class RDMAPI {
     // Handlers, these are called by the RDMAPIImpl.
 
     // Generic handlers
+    void _HandleCustomLengthLabelResponse(
+        ola::SingleUseCallback2<void,
+                                const ResponseStatus&,
+                                const std::string&> *callback,
+        uint8_t length,
+        const ResponseStatus &status,
+        const std::string &data);
+
     void _HandleLabelResponse(
         ola::SingleUseCallback2<void,
                                 const ResponseStatus&,
@@ -1165,8 +1207,6 @@ class RDMAPI {
     class RDMAPIImplInterface *m_impl;
     std::map<UID, uint8_t> m_outstanding_messages;
 
-    enum {LABEL_SIZE = 32};
-
     bool GenericGetU8(
         unsigned int universe,
         const UID &uid,
