@@ -48,6 +48,20 @@ typedef enum {
   RDM_VERSION_1_0 = 0x100,
 } rdm_protocol_version;
 
+/**
+ * @brief A set of values representing CommandClasses in E1.20.
+ * @note See section 6.2.10 of ANSI E1.20 for more information.
+ */
+typedef enum {
+  DISCOVER_COMMAND = 0x10, /**< Discovery Command */
+  DISCOVER_COMMAND_RESPONSE = 0x11, /**< Discovery Response */
+  GET_COMMAND = 0x20, /**< Get Command */
+  GET_COMMAND_RESPONSE = 0x21, /**< Get Response */
+  SET_COMMAND = 0x30, /**< Set Command */
+  SET_COMMAND_RESPONSE = 0x31, /**< Set Response */
+  INVALID_COMMAND = 0xff, /**< Invalid Command, specific to OLA */
+} RDMCommandClass;
+
 typedef enum {
   // discovery
   PID_DISC_UNIQUE_BRANCH = 0x0001,
@@ -615,6 +629,7 @@ typedef enum {
   DISPLAY_INVERT_OFF = 0x00,
   DISPLAY_INVERT_ON = 0x01,
   DISPLAY_INVERT_AUTO = 0x02,
+  DISPLAY_INVERT_MAX,
 } rdm_display_invert;
 
 // The identify modes from E1.37-1
