@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * UID.h
  * Representation of an RDM UID
- * Copyright (C) 2005-2010 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 /**
@@ -183,7 +183,7 @@ class UID {
      * @returns a string in the form XXXX:YYYYYYYY.
      */
     std::string ToString() const {
-      std::stringstream str;
+      std::ostringstream str;
       str << std::setfill('0') << std::setw(4) << std::hex << m_uid.esta_id
         << ":" << std::setw(8) << m_uid.device_id;
       return str.str();
