@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * SignalThread.h
  * A thread to handle signals.
@@ -49,7 +49,7 @@ class SignalThread : public ola::thread::Thread {
  public:
     typedef ola::Callback0<void> SignalHandler;
 
-    SignalThread() {}
+    SignalThread();
     ~SignalThread();
 
     // This has to be called before Start(). You can't add signal handlers once
