@@ -29,27 +29,29 @@
 #include <vector>
 
 #include "common/protocol/Ola.pb.h"
-#include "ola/BaseTypes.h"
 #include "ola/Callback.h"
+#include "ola/ClientTypesFactory.h"
+#include "ola/Constants.h"
 #include "ola/Logging.h"
 #include "ola/OlaClientCore.h"
 #include "ola/client/ClientTypes.h"
 #include "ola/network/NetworkUtils.h"
 #include "ola/rdm/RDMCommand.h"
 #include "ola/rdm/RDMEnums.h"
+#include "ola/rdm/RDMFrame.h"
 
 namespace ola {
 namespace client {
 
 using ola::io::ConnectedDescriptor;
 using ola::proto::OlaServerService_Stub;
+using ola::rdm::UID;
+using ola::rdm::UIDSet;
 using ola::rpc::RpcChannel;
 using ola::rpc::RpcController;
 using std::auto_ptr;
 using std::string;
 using std::vector;
-using ola::rdm::UID;
-using ola::rdm::UIDSet;
 
 const char OlaClientCore::NOT_CONNECTED_ERROR[] = "Not connected";
 
@@ -106,8 +108,13 @@ bool OlaClientCore::Stop() {
 /**
  * Set the close handler.
  */
-void OlaClientCore::SetCloseHandler(ola::SingleUseCallback0<void> *callback) {
-  m_channel->SetChannelCloseHandler(callback);
+void OlaClientCore::SetCloseHandler(ClosedCallback *callback) {
+  if (callback) {
+    m_channel->SetChannelCloseHandler(
+        NewSingleCallback(this, &OlaClientCore::ChannelClosed, callback));
+  } else {
+    m_channel->SetChannelCloseHandler(NULL);
+  }
 }
 
 void OlaClientCore::SetDMXCallback(RepeatableDMXCallback *callback) {
@@ -245,6 +252,28 @@ void OlaClientCore::ConfigureDevice(
   }
 }
 
+void OlaClientCore::SetPluginState(ola_plugin_id plugin_id,
+                                   bool state,
+                                   SetCallback *callback) {
+  ola::proto::PluginStateChangeRequest request;
+  RpcController *controller = new RpcController();
+  ola::proto::Ack *reply = new ola::proto::Ack();
+
+  request.set_plugin_id(plugin_id);
+  request.set_enabled(state);
+
+  if (m_connected) {
+    CompletionCallback *cb = ola::NewSingleCallback(
+        this,
+        &OlaClientCore::HandleAck,
+        controller, reply, callback);
+    m_stub->SetPluginState(controller, &request, reply, cb);
+  } else {
+    controller->SetFailed(NOT_CONNECTED_ERROR);
+    HandleAck(controller, reply, callback);
+  }
+}
+
 void OlaClientCore::SetPortPriorityInherit(unsigned int device_alias,
                                            unsigned int port,
                                            PortDirection port_direction,
@@ -608,6 +637,11 @@ void OlaClientCore::UpdateDmxData(ola::rpc::RpcController*,
   done->Run();
 }
 
+void OlaClientCore::ChannelClosed(ClosedCallback *callback,
+                                  OLA_UNUSED ola::rpc::RpcSession *session) {
+  callback->Run();
+}
+
 
 // The following are RPC callbacks
 
@@ -630,10 +664,8 @@ void OlaClientCore::HandlePluginList(RpcController *controller_ptr,
   if (!controller->Failed()) {
     for (int i = 0; i < reply->plugin_size(); ++i) {
       ola::proto::PluginInfo plugin_info = reply->plugin(i);
-      OlaPlugin plugin(plugin_info.plugin_id(),
-                       plugin_info.name(),
-                       plugin_info.active());
-      ola_plugins.push_back(plugin);
+      ola_plugins.push_back(
+          ClientTypesFactory::PluginFromProtobuf(plugin_info));
     }
   }
   std::sort(ola_plugins.begin(), ola_plugins.end());
@@ -689,10 +721,8 @@ void OlaClientCore::HandlePluginState(
     plugin_state.preferences_source = reply->preferences_source();
     for (int i = 0; i < reply->conflicts_with_size(); ++i) {
       ola::proto::PluginInfo plugin_info = reply->conflicts_with(i);
-      OlaPlugin plugin(plugin_info.plugin_id(),
-                       plugin_info.name(),
-                       plugin_info.active());
-      plugin_state.conflicting_plugins.push_back(plugin);
+      plugin_state.conflicting_plugins.push_back(
+          ClientTypesFactory::PluginFromProtobuf(plugin_info));
     }
   }
 
@@ -719,48 +749,8 @@ void OlaClientCore::HandleDeviceInfo(RpcController *controller_ptr,
   if (!controller->Failed()) {
     for (int i = 0; i < reply->device_size(); ++i) {
       ola::proto::DeviceInfo device_info = reply->device(i);
-      vector<OlaInputPort> input_ports;
-
-      for (int j = 0; j < device_info.input_port_size(); ++j) {
-        ola::proto::PortInfo port_info = device_info.input_port(j);
-        OlaInputPort port(
-            port_info.port_id(),
-            port_info.universe(),
-            port_info.active(),
-            port_info.description(),
-            static_cast<port_priority_capability>(
-              port_info.priority_capability()),
-            static_cast<port_priority_mode>(
-              port_info.priority_mode()),
-            port_info.priority(),
-            port_info.supports_rdm());
-        input_ports.push_back(port);
-      }
-
-      vector<OlaOutputPort> output_ports;
-      for (int j = 0; j < device_info.output_port_size(); ++j) {
-        ola::proto::PortInfo port_info = device_info.output_port(j);
-        OlaOutputPort port(
-            port_info.port_id(),
-            port_info.universe(),
-            port_info.active(),
-            port_info.description(),
-            static_cast<port_priority_capability>(
-              port_info.priority_capability()),
-            static_cast<port_priority_mode>(
-              port_info.priority_mode()),
-            port_info.priority(),
-            port_info.supports_rdm());
-        output_ports.push_back(port);
-      }
-
-      OlaDevice device(device_info.device_id(),
-                       device_info.device_alias(),
-                       device_info.device_name(),
-                       device_info.plugin_id(),
-                       input_ports,
-                       output_ports);
-      ola_devices.push_back(device);
+      ola_devices.push_back(
+          ClientTypesFactory::DeviceFromProtobuf(device_info));
     }
   }
   std::sort(ola_devices.begin(), ola_devices.end());
@@ -830,17 +820,8 @@ void OlaClientCore::HandleUniverseList(RpcController *controller_ptr,
   if (!controller->Failed()) {
     for (int i = 0; i < reply->universe_size(); ++i) {
       ola::proto::UniverseInfo universe_info = reply->universe(i);
-      OlaUniverse::merge_mode merge_mode = (
-        universe_info.merge_mode() == ola::proto::HTP ?
-        OlaUniverse::MERGE_HTP: OlaUniverse::MERGE_LTP);
-
-      OlaUniverse universe(universe_info.universe(),
-                           merge_mode,
-                           universe_info.name(),
-                           universe_info.input_port_count(),
-                           universe_info.output_port_count(),
-                           universe_info.rdm_devices());
-      ola_universes.push_back(universe);
+      ola_universes.push_back(
+          ClientTypesFactory::UniverseFromProtobuf(universe_info));
     }
   }
   callback->Run(result, ola_universes);
@@ -858,21 +839,16 @@ void OlaClientCore::HandleUniverseInfo(RpcController *controller_ptr,
 
   string error_str(controller->Failed() ? controller->ErrorText() : "");
 
-  OlaUniverse null_universe(0, OlaUniverse::MERGE_LTP, "", 0, 0, 0);
+  OlaUniverse null_universe(0, OlaUniverse::MERGE_LTP, "",
+                            std::vector<OlaInputPort>(),
+                            std::vector<OlaOutputPort>(),
+                            0);
 
   if (!controller->Failed()) {
     if (reply->universe_size() == 1) {
       ola::proto::UniverseInfo universe_info = reply->universe(0);
-      OlaUniverse::merge_mode merge_mode = (
-        universe_info.merge_mode() == ola::proto::HTP ?
-        OlaUniverse::MERGE_HTP: OlaUniverse::MERGE_LTP);
-
-      OlaUniverse universe(universe_info.universe(),
-                           merge_mode,
-                           universe_info.name(),
-                           universe_info.input_port_count(),
-                           universe_info.output_port_count(),
-                           universe_info.rdm_devices());
+      OlaUniverse universe =
+          ClientTypesFactory::UniverseFromProtobuf(universe_info);
       Result result(error_str);
       callback->Run(result, universe);
       return;
@@ -947,7 +923,20 @@ void OlaClientCore::HandleRDM(RpcController *controller_ptr,
 
   if (!controller->Failed()) {
     response = BuildRDMResponse(reply.get(), &metadata.response_code);
+    for (int i = 0; i < reply->raw_frame_size(); i++) {
+      const ola::proto::RDMFrame &proto_frame = reply->raw_frame(i);
+
+      ola::rdm::RDMFrame frame(
+          reinterpret_cast<const uint8_t*>(proto_frame.raw_response().data()),
+          proto_frame.raw_response().size());
+      frame.timing.response_time = proto_frame.timing().response_delay();
+      frame.timing.break_time = proto_frame.timing().break_time();
+      frame.timing.mark_time = proto_frame.timing().mark_time();
+      frame.timing.data_time = proto_frame.timing().data_time();
+      metadata.frames.push_back(frame);
+    }
   }
+
   callback->Run(result, metadata, response);
 }
 
@@ -1010,6 +999,10 @@ void OlaClientCore::SendRDMCommand(bool is_set,
   request.set_is_set(is_set);
   request.set_data(string(reinterpret_cast<const char*>(data), data_length));
 
+  if (args.include_raw_frames) {
+    request.set_include_raw_response(true);
+  }
+
   CompletionCallback *cb = NewSingleCallback(
       this,
       &OlaClientCore::HandleRDM,
@@ -1024,12 +1017,12 @@ void OlaClientCore::SendRDMCommand(bool is_set,
  */
 ola::rdm::RDMResponse *OlaClientCore::BuildRDMResponse(
     ola::proto::RDMResponse *reply,
-    ola::rdm::rdm_response_code *response_code) {
+    ola::rdm::RDMStatusCode *status_code) {
   // Get the response code, if it's not RDM_COMPLETED_OK don't bother with the
   // rest of the response data.
-  *response_code = static_cast<ola::rdm::rdm_response_code>(
+  *status_code = static_cast<ola::rdm::RDMStatusCode>(
       reply->response_code());
-  if (*response_code != ola::rdm::RDM_COMPLETED_OK) {
+  if (*status_code != ola::rdm::RDM_COMPLETED_OK) {
     return NULL;
   }
 
