@@ -20,7 +20,7 @@
 
 #include <ola/OlaClientWrapper.h>
 
-#include <ola/BaseTypes.h>
+#include <ola/Constants.h>
 #include <ola/Logging.h>
 #include <ola/network/IPV4Address.h>
 #include <ola/network/SocketAddress.h>
