@@ -28,62 +28,46 @@
 namespace ola {
 
 using std::set;
+using std::string;
+using std::vector;
 
-/**
- * Add a client to the broker
- */
 void ClientBroker::AddClient(const Client *client) {
   m_clients.insert(client);
 }
 
-
-/**
- * Remove a client from the broker
- */
 void ClientBroker::RemoveClient(const Client *client) {
   m_clients.erase(client);
 }
 
-
-/**
- * Make an RDM call
- * @param client the OlaClientService that should exist when the call returns
- * @param universe the universe to send the RDM request on
- * @param request the RDM request
- * @param callback the callback to run when the request completes
- */
 void ClientBroker::SendRDMRequest(const Client *client,
                                   Universe *universe,
-                                  const ola::rdm::RDMRequest *request,
+                                  ola::rdm::RDMRequest *request,
                                   ola::rdm::RDMCallback *callback) {
   if (!STLContains(m_clients, client))
     OLA_WARN <<
       "Making an RDM call but the client doesn't exist in the broker!";
 
-  universe->SendRDMRequest(request,
+  universe->SendRDMRequest(
+      request,
       NewSingleCallback(this, &ClientBroker::RequestComplete, client,
                         callback));
 }
 
-
-/**
- * Return from an RDM call
+/*
+ * Return from an RDM call.
  * @param key the client associated with this request
  * @param callback the callback to run if the key still exists
  * @param code the code of the RDM request
  * @param response the RDM response
  */
-void ClientBroker::RequestComplete(const Client *key,
+void ClientBroker::RequestComplete(const Client *client,
                                    ola::rdm::RDMCallback *callback,
-                                   ola::rdm::rdm_response_code code,
-                                   const ola::rdm::RDMResponse *response,
-                                   const std::vector<std::string> &packets) {
-  if (!STLContains(m_clients, key)) {
-    OLA_INFO << "Client no longer exists, cleaning up from RDM response";
-    delete response;
+                                   ola::rdm::RDMReply *reply) {
+  if (!STLContains(m_clients, client)) {
+    OLA_DEBUG << "Client no longer exists, cleaning up from RDM response";
     delete callback;
   } else {
-    callback->Run(code, response, packets);
+    callback->Run(reply);
   }
 }
 }  // namespace ola
