@@ -60,7 +60,6 @@ DEFINE_string(pid_location, "",
 DEFINE_s_uint16(http_port, p, ola::OlaServer::DEFAULT_HTTP_PORT,
                 "The port to run the http server on. Defaults to 9090.");
 
-
 /**
  * This is called by the SelectServer loop to start up the SignalThread. If the
  * thread fails to start, we terminate the SelectServer
@@ -109,7 +108,9 @@ int main(int argc, char *argv[]) {
 #endif
 
   ola::ExportMap export_map;
-  ola::ServerInit(original_argc, original_argv, &export_map);
+  if (!ola::ServerInit(original_argc, original_argv, &export_map)) {
+    return ola::EXIT_UNAVAILABLE;
+  }
 
   // We need to block signals before we start any threads.
   // Signal setup is complex. First of all we need to install NULL handlers to
