@@ -47,7 +47,7 @@ class AbstractPlugin;
  * rest of the conflicting plugins are ignored.
  *
  * Plugins are active if they weren't disabled, there were no conflicts that
- * prevented them from laoding, and the call to Start() was successfull.
+ * prevented them from loading, and the call to Start() was successfull.
  */
 class PluginManager {
  public:
@@ -90,6 +90,12 @@ class PluginManager {
    */
   void ActivePlugins(std::vector<AbstractPlugin*> *plugins) const;
 
+  /**
+   * @brief Return a list of enabled plugins.
+   * @param[out] plugins the list of enabled plugins.
+   */
+  void EnabledPlugins(std::vector<AbstractPlugin*> *plugins) const;
+
   /**
    * @brief Lookup a plugin by ID.
    * @param plugin_id the id of the plugin to find.
@@ -104,6 +110,30 @@ class PluginManager {
    */
   bool IsActive(ola_plugin_id plugin_id) const;
 
+  /**
+   * @brief Check if a plugin is enabled.
+   * @param plugin_id the id of the plugin to check.
+   * @returns true if the plugin is enabled, false otherwise.
+   */
+  bool IsEnabled(ola_plugin_id plugin_id) const;
+
+  /**
+   * @brief Enable & start a plugin
+   * @param plugin_id the id of the plugin to start.
+   * @returns true if the plugin was started or was already running, false if
+   * it couldn't be started.
+   *
+   * This call will enable a plugin, but may not start it due to conflicts with
+   * existing plugins.
+   */
+  bool EnableAndStartPlugin(ola_plugin_id plugin_id);
+
+  /**
+   * @brief Disable & stop a plugin.
+   * @param plugin_id the id of the plugin to stop.
+   */
+  void DisableAndStopPlugin(ola_plugin_id plugin_id);
+
   /**
    * @brief Return a list of plugins that conflict with this particular plugin.
    * @param plugin_id the id of the plugin to check.
@@ -118,8 +148,12 @@ class PluginManager {
   std::vector<PluginLoader*> m_plugin_loaders;
   PluginMap m_loaded_plugins;  // plugins that are loaded
   PluginMap m_active_plugins;  // active plugins
+  PluginMap m_enabled_plugins;  // enabled plugins
   PluginAdaptor *m_plugin_adaptor;
 
+  bool StartIfSafe(AbstractPlugin *plugin);
+  AbstractPlugin* CheckForRunningConflicts(const AbstractPlugin *plugin) const;
+
   DISALLOW_COPY_AND_ASSIGN(PluginManager);
 };
 }  // namespace ola
