@@ -24,9 +24,11 @@
 #include <vector>
 
 #include "ola/Callback.h"
+#include "ola/Constants.h"
 #include "ola/Clock.h"
 #include "ola/DmxBuffer.h"
 #include "ola/rdm/RDMCommand.h"
+#include "ola/rdm/RDMReply.h"
 #include "ola/rdm/RDMResponseCodes.h"
 #include "ola/rdm/UID.h"
 #include "olad/Client.h"
@@ -51,11 +53,12 @@ using ola::TimeStamp;
 using ola::Universe;
 using ola::rdm::NewDiscoveryUniqueBranchRequest;
 using ola::rdm::RDMCallback;
+using ola::rdm::RDMReply;
 using ola::rdm::RDMRequest;
 using ola::rdm::RDMResponse;
 using ola::rdm::UID;
 using ola::rdm::UIDSet;
-using ola::rdm::rdm_response_code;
+using ola::rdm::RDMStatusCode;
 using std::string;
 using std::vector;
 
@@ -78,56 +81,57 @@ class UniverseTest: public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE_END();
 
  public:
-    void setUp();
-    void tearDown();
-    void testLifecycle();
-    void testSetGetDmx();
-    void testSendDmx();
-    void testReceiveDmx();
-    void testSourceClients();
-    void testSinkClients();
-    void testLtpMerging();
-    void testHtpMerging();
-    void testRDMDiscovery();
-    void testRDMSend();
+  void setUp();
+  void tearDown();
+  void testLifecycle();
+  void testSetGetDmx();
+  void testSendDmx();
+  void testReceiveDmx();
+  void testSourceClients();
+  void testSinkClients();
+  void testLtpMerging();
+  void testHtpMerging();
+  void testRDMDiscovery();
+  void testRDMSend();
 
  private:
-    ola::MemoryPreferences *m_preferences;
-    ola::UniverseStore *m_store;
-    DmxBuffer m_buffer;
-    ola::Clock m_clock;
+  ola::MemoryPreferences *m_preferences;
+  ola::UniverseStore *m_store;
+  DmxBuffer m_buffer;
+  ola::Clock m_clock;
 
-    void ConfirmUIDs(UIDSet *expected, const UIDSet &uids);
+  void ConfirmUIDs(UIDSet *expected, const UIDSet &uids);
 
-    void ConfirmRDM(int line,
-                    rdm_response_code expected_response_code,
-                    const RDMResponse *expected_response,
-                    rdm_response_code response_code,
-                    const RDMResponse *response,
-                    const vector<string>&);
+  void ConfirmRDM(int line,
+                  RDMStatusCode expected_status_code,
+                  const RDMResponse *expected_response,
+                  RDMReply *reply);
 
-    void ReturnRDMCode(rdm_response_code response_code,
-                       const RDMRequest *request,
-                       RDMCallback *callback) {
-      vector<string> packets;
-      delete request;
-      callback->Run(response_code, NULL, packets);
-    }
+  void ReturnRDMCode(RDMStatusCode status_code,
+                     const RDMRequest *request,
+                     RDMCallback *callback) {
+    delete request;
+    RunRDMCallback(callback, status_code);
+  }
 };
 
 
 class MockClient: public ola::Client {
  public:
-    MockClient(): ola::Client(NULL), m_dmx_set(false) {}
-    bool SendDMX(unsigned int universe_id, uint8_t priority,
-                 const DmxBuffer &buffer) {
-      OLA_ASSERT_EQ(TEST_UNIVERSE, universe_id);
-      OLA_ASSERT_EQ(ola::dmx::SOURCE_PRIORITY_MIN, priority);
-      OLA_ASSERT_EQ(string(TEST_DATA), buffer.Get());
-      m_dmx_set = true;
-      return true;
-    }
-    bool m_dmx_set;
+  MockClient()
+      : ola::Client(NULL, UID(ola::OPEN_LIGHTING_ESTA_CODE, 0)),
+        m_dmx_set(false) {
+  }
+
+  bool SendDMX(unsigned int universe_id, uint8_t priority,
+               const DmxBuffer &buffer) {
+    OLA_ASSERT_EQ(TEST_UNIVERSE, universe_id);
+    OLA_ASSERT_EQ(ola::dmx::SOURCE_PRIORITY_MIN, priority);
+    OLA_ASSERT_EQ(string(TEST_DATA), buffer.Get());
+    m_dmx_set = true;
+    return true;
+  }
+  bool m_dmx_set;
 };
 
 
@@ -141,13 +145,11 @@ void UniverseTest::setUp() {
   m_buffer.Set(TEST_DATA);
 }
 
-
 void UniverseTest::tearDown() {
   delete m_store;
   delete m_preferences;
 }
 
-
 /*
  * Test that we can create universes and save their settings
  */
@@ -239,7 +241,7 @@ void UniverseTest::testReceiveDmx() {
   ola::PortManager port_manager(m_store, &broker);
   TimeStamp time_stamp;
   MockSelectServer ss(&time_stamp);
-  ola::PluginAdaptor plugin_adaptor(NULL, &ss, NULL, NULL, NULL);
+  ola::PluginAdaptor plugin_adaptor(NULL, &ss, NULL, NULL, NULL, NULL);
 
   MockDevice device(NULL, "foo");
   TestMockInputPort port(&device, 1, &plugin_adaptor);  // input port
@@ -364,7 +366,7 @@ void UniverseTest::testLtpMerging() {
 
   TimeStamp time_stamp;
   MockSelectServer ss(&time_stamp);
-  ola::PluginAdaptor plugin_adaptor(NULL, &ss, NULL, NULL, NULL);
+  ola::PluginAdaptor plugin_adaptor(NULL, &ss, NULL, NULL, NULL, NULL);
   MockDevice device(NULL, "foo");
   MockDevice device2(NULL, "bar");
   TestMockInputPort port(&device, 1, &plugin_adaptor);  // input port
@@ -444,7 +446,7 @@ void UniverseTest::testHtpMerging() {
 
   TimeStamp time_stamp;
   MockSelectServer ss(&time_stamp);
-  ola::PluginAdaptor plugin_adaptor(NULL, &ss, NULL, NULL, NULL);
+  ola::PluginAdaptor plugin_adaptor(NULL, &ss, NULL, NULL, NULL, NULL);
   MockDevice device(NULL, "foo");
   MockDevice device2(NULL, "bar");
   TestMockInputPort port(&device, 1, &plugin_adaptor);  // input port
@@ -614,12 +616,11 @@ void UniverseTest::testRDMSend() {
 
   UID source_uid(0x7a70, 100);
   // first try a command to a uid we don't know about
-  const RDMRequest *request = new ola::rdm::RDMGetRequest(
+  RDMRequest *request = new ola::rdm::RDMGetRequest(
       source_uid,
       uid3,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       10,  // sub device
       296,  // param id
       NULL,
@@ -639,7 +640,6 @@ void UniverseTest::testRDMSend() {
       uid1,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       10,  // sub device
       296,  // param id
       NULL,
@@ -663,7 +663,6 @@ void UniverseTest::testRDMSend() {
       vendorcast_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       10,  // sub device
       296,  // param id
       NULL,
@@ -692,7 +691,6 @@ void UniverseTest::testRDMSend() {
       vendorcast_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       10,  // sub device
       296,  // param id
       NULL,
@@ -814,15 +812,13 @@ void UniverseTest::ConfirmUIDs(UIDSet *expected, const UIDSet &uids) {
  * Confirm an RDM response
  */
 void UniverseTest::ConfirmRDM(int line,
-                              rdm_response_code expected_response_code,
+                              RDMStatusCode expected_status_code,
                               const RDMResponse *expected_response,
-                              rdm_response_code response_code,
-                              const RDMResponse *response,
-                              const vector<string>&) {
+                              RDMReply *reply) {
   std::ostringstream str;
   str << "Line " << line;
-  OLA_ASSERT_EQ_MSG(expected_response_code,
-                    response_code,
+  OLA_ASSERT_EQ_MSG(expected_status_code,
+                    reply->StatusCode(),
                     str.str());
-  OLA_ASSERT_EQ_MSG(expected_response, response, str.str());
+  OLA_ASSERT_EQ_MSG(expected_response, reply->Response(), str.str());
 }
