@@ -35,6 +35,7 @@
 #include "ola/network/Socket.h"
 #include "ola/rdm/RDMCommand.h"
 #include "ola/rdm/RDMCommandSerializer.h"
+#include "ola/rdm/RDMReply.h"
 #include "ola/rdm/RDMResponseCodes.h"
 #include "ola/rdm/UID.h"
 #include "ola/rdm/UIDSet.h"
@@ -45,7 +46,6 @@
 #include "ola/testing/TestUtils.h"
 
 
-
 using ola::DmxBuffer;
 using ola::network::IPV4Address;
 using ola::network::Interface;
@@ -56,6 +56,7 @@ using ola::rdm::RDMCallback;
 using ola::rdm::RDMCommand;
 using ola::rdm::RDMCommandSerializer;
 using ola::rdm::RDMGetRequest;
+using ola::rdm::RDMReply;
 using ola::rdm::RDMRequest;
 using ola::rdm::RDMResponse;
 using ola::rdm::UID;
@@ -145,7 +146,7 @@ class ArtNetNodeTest: public CppUnit::TestFixture {
   RDMCallback *m_rdm_callback;
   const RDMResponse *m_rdm_response;
   uint8_t m_port_id;
-  Interface interface;
+  Interface iface;
   IPV4Address peer_ip, peer_ip2, peer_ip3;
   IPV4Address broadcast_ip;
   MockUDPSocket *m_socket;
@@ -163,25 +164,19 @@ class ArtNetNodeTest: public CppUnit::TestFixture {
   void TodRequest() { m_tod_request = true; }
   void Flush() { m_tod_flush = true; }
 
-  void HandleRDM(const RDMRequest *request, RDMCallback *callback) {
+  void HandleRDM(RDMRequest *request, RDMCallback *callback) {
     m_rdm_request = request;
     m_rdm_callback = callback;
   }
 
-  void FinalizeRDM(ola::rdm::rdm_response_code status,
-                   const RDMResponse *response,
-                   const vector<string> &packets) {
-    OLA_ASSERT_EQ(ola::rdm::RDM_COMPLETED_OK, status);
-    m_rdm_response = response;
-    (void) packets;
+  void FinalizeRDM(RDMReply *reply) {
+    OLA_ASSERT_EQ(ola::rdm::RDM_COMPLETED_OK, reply->StatusCode());
+    m_rdm_response = reply->Response()->Duplicate();
   }
 
-  void ExpectTimeout(ola::rdm::rdm_response_code status,
-                     const RDMResponse *response,
-                     const vector<string> &packets) {
-    OLA_ASSERT_EQ(ola::rdm::RDM_TIMEOUT, status);
-    OLA_ASSERT(NULL == response);
-    (void) packets;
+  void ExpectTimeout(RDMReply *reply) {
+    OLA_ASSERT_EQ(ola::rdm::RDM_TIMEOUT, reply->StatusCode());
+    OLA_ASSERT_NULL(reply->Response());
     m_got_rdm_timeout = true;
   }
 
@@ -192,13 +187,13 @@ class ArtNetNodeTest: public CppUnit::TestFixture {
   }
 
   void ExpectedBroadcast(const uint8_t *data, unsigned int data_size) {
-    ExpectedSend(data, data_size, interface.bcast_address);
+    ExpectedSend(data, data_size, iface.bcast_address);
   }
 
   void ReceiveFromPeer(const uint8_t *data,
                        unsigned int data_size,
                        const IPV4Address &address) {
-    ss.RunOnce(0, 0);  // update the wake up time
+    ss.RunOnce();  // update the wake up time
     m_socket->InjectData(data, data_size, address, ARTNET_PORT);
   }
 
@@ -241,12 +236,11 @@ class ArtNetNodeTest: public CppUnit::TestFixture {
     UID source(1, 2);
     UID destination(0x7a70, 0);
 
-    const RDMGetRequest *request = new RDMGetRequest(
+    RDMGetRequest *request = new RDMGetRequest(
         source,
         destination,
         0,  // transaction #
         1,  // port id
-        0,  // message count
         10,  // sub device
         296,  // param id
         NULL,  // data
@@ -349,7 +343,7 @@ void ArtNetNodeTest::setUp() {
   OLA_ASSERT(interface_builder.SetBroadcast("10.255.255.255"));
   interface_builder.SetHardwareAddress(
       MACAddress::FromStringOrDie("0a:0b:0c:12:34:56"));
-  interface = interface_builder.Construct();
+  iface = interface_builder.Construct();
 
   ola::network::IPV4Address::FromString("10.0.0.10", &peer_ip);
   ola::network::IPV4Address::FromString("10.0.0.11", &peer_ip2);
@@ -362,7 +356,7 @@ void ArtNetNodeTest::setUp() {
  */
 void ArtNetNodeTest::testBasicBehaviour() {
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
 
   node.SetShortName("Short Name");
   OLA_ASSERT_EQ(string("Short Name"), node.ShortName());
@@ -428,7 +422,7 @@ void ArtNetNodeTest::testBasicBehaviour() {
  */
 void ArtNetNodeTest::testConfigurationMode() {
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
 
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -602,7 +596,7 @@ void ArtNetNodeTest::testConfigurationMode() {
 void ArtNetNodeTest::testExtendedInputPorts() {
   ArtNetNodeOptions node_options;
   node_options.input_port_count = 8;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
 
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -642,7 +636,7 @@ void ArtNetNodeTest::testBroadcastSendDMX() {
 
   ArtNetNodeOptions node_options;
   node_options.always_broadcast = true;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
 
   OLA_ASSERT(node.Start());
@@ -710,7 +704,7 @@ void ArtNetNodeTest::testBroadcastSendDMXZeroUniverse() {
 
   ArtNetNodeOptions node_options;
   node_options.always_broadcast = true;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
 
   node.SetNetAddress(0);
   node.SetSubnetAddress(0);
@@ -814,7 +808,7 @@ void ArtNetNodeTest::testLimitedBroadcastDMX() {
   ArtNetNodeOptions node_options;
   node_options.always_broadcast = true;
   node_options.use_limited_broadcast_address = true;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
 
   OLA_ASSERT(node.Start());
@@ -849,7 +843,7 @@ void ArtNetNodeTest::testLimitedBroadcastDMX() {
 void ArtNetNodeTest::testNonBroadcastSendDMX() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -1030,7 +1024,7 @@ void ArtNetNodeTest::testNonBroadcastSendDMX() {
 void ArtNetNodeTest::testReceiveDMX() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupOutputPort(&node);
   DmxBuffer input_buffer;
   node.SetDMXHandler(m_port_id,
@@ -1104,7 +1098,7 @@ void ArtNetNodeTest::testReceiveDMX() {
 void ArtNetNodeTest::testReceiveDMXZeroUniverse() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
 
   node.SetNetAddress(0);
   node.SetSubnetAddress(0);
@@ -1177,7 +1171,7 @@ void ArtNetNodeTest::testReceiveDMXZeroUniverse() {
 void ArtNetNodeTest::testHTPMerge() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupOutputPort(&node);
   DmxBuffer input_buffer;
   node.SetDMXHandler(m_port_id,
@@ -1370,7 +1364,7 @@ void ArtNetNodeTest::testHTPMerge() {
 void ArtNetNodeTest::testLTPMerge() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupOutputPort(&node);
   DmxBuffer input_buffer;
   node.SetDMXHandler(m_port_id,
@@ -1539,7 +1533,7 @@ void ArtNetNodeTest::testLTPMerge() {
 void ArtNetNodeTest::testControllerDiscovery() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -1564,7 +1558,7 @@ void ArtNetNodeTest::testControllerDiscovery() {
   {
     SocketVerifier verifer(m_socket);
     m_clock.AdvanceTime(5, 0);  // tod timeout is 4s
-    ss.RunOnce(0, 0);  // update the wake up time
+    ss.RunOnce();  // update the wake up time
     OLA_ASSERT(m_discovery_done);
 
     UIDSet uids;
@@ -1609,7 +1603,7 @@ void ArtNetNodeTest::testControllerDiscovery() {
   {
     SocketVerifier verifer(m_socket);
     m_clock.AdvanceTime(5, 0);  // tod timeout is 4s
-    ss.RunOnce(0, 0);  // update the wake up time
+    ss.RunOnce();  // update the wake up time
     OLA_ASSERT(m_discovery_done);
 
     UIDSet uids;
@@ -1675,7 +1669,7 @@ void ArtNetNodeTest::testControllerDiscovery() {
   {
     SocketVerifier verifer(m_socket);
     m_clock.AdvanceTime(5, 0);  // tod timeout is 4s
-    ss.RunOnce(0, 0);  // update the wake up time
+    ss.RunOnce();  // update the wake up time
     OLA_ASSERT(m_discovery_done);
 
     UIDSet uids;
@@ -1704,7 +1698,7 @@ void ArtNetNodeTest::testControllerDiscovery() {
 void ArtNetNodeTest::testControllerIncrementalDiscovery() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -1760,7 +1754,7 @@ void ArtNetNodeTest::testControllerIncrementalDiscovery() {
 
     // advance the clock and run the select server
     m_clock.AdvanceTime(5, 0);  // tod timeout is 4s
-    ss.RunOnce(0, 0);  // update the wake up time
+    ss.RunOnce();  // update the wake up time
     OLA_ASSERT(m_discovery_done);
 
     UIDSet uids;
@@ -1789,7 +1783,7 @@ void ArtNetNodeTest::testControllerIncrementalDiscovery() {
 void ArtNetNodeTest::testUnsolicitedTod() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
   OLA_ASSERT(node.SetUnsolicitedUIDSetHandler(
       m_port_id,
@@ -1838,7 +1832,7 @@ void ArtNetNodeTest::testUnsolicitedTod() {
 void ArtNetNodeTest::testResponderDiscovery() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupOutputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -1971,7 +1965,7 @@ void ArtNetNodeTest::testResponderDiscovery() {
 void ArtNetNodeTest::testRDMResponder() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupOutputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -2023,11 +2017,10 @@ void ArtNetNodeTest::testRDMResponder() {
     OLA_ASSERT_EQ(RDMCommand::GET_COMMAND,
                   m_rdm_request->CommandClass());
     OLA_ASSERT_EQ((uint16_t) 296, m_rdm_request->ParamId());
-    OLA_ASSERT_EQ(static_cast<uint8_t*>(NULL),
+    OLA_ASSERT_EQ(static_cast<const uint8_t*>(NULL),
                   m_rdm_request->ParamData());
     OLA_ASSERT_EQ(0u, m_rdm_request->ParamDataSize());
     OLA_ASSERT_EQ(25u, RDMCommandSerializer::RequiredSize(*m_rdm_request));
-    OLA_ASSERT_EQ(ola::rdm::RDM_REQUEST, m_rdm_request->CommandType());
   }
 
   // run the RDM callback, triggering the response
@@ -2057,8 +2050,8 @@ void ArtNetNodeTest::testRDMResponder() {
     RDMResponse *response = GetResponseFromData(m_rdm_request,
                                                 param_data,
                                                 sizeof(param_data));
-    vector<string> packets;
-    m_rdm_callback->Run(ola::rdm::RDM_COMPLETED_OK, response, packets);
+    RDMReply reply(ola::rdm::RDM_COMPLETED_OK, response);
+    m_rdm_callback->Run(&reply);
 
     // clean up
     delete m_rdm_request;
@@ -2073,7 +2066,7 @@ void ArtNetNodeTest::testRDMResponder() {
 void ArtNetNodeTest::testRDMRequest() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -2127,7 +2120,7 @@ void ArtNetNodeTest::testRDMRequest() {
 void ArtNetNodeTest::testRDMRequestTimeout() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -2146,7 +2139,7 @@ void ArtNetNodeTest::testRDMRequestTimeout() {
   }
 
   m_clock.AdvanceTime(3, 0);  // timeout is 2s
-  ss.RunOnce(0, 0);
+  ss.RunOnce();
   OLA_ASSERT(m_got_rdm_timeout);
 }
 
@@ -2157,7 +2150,7 @@ void ArtNetNodeTest::testRDMRequestTimeout() {
 void ArtNetNodeTest::testRDMRequestIPMismatch() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -2203,7 +2196,7 @@ void ArtNetNodeTest::testRDMRequestIPMismatch() {
   }
 
   m_clock.AdvanceTime(3, 0);  // timeout is 2s
-  ss.RunOnce(0, 0);
+  ss.RunOnce();
   OLA_ASSERT(m_got_rdm_timeout);
 }
 
@@ -2214,7 +2207,7 @@ void ArtNetNodeTest::testRDMRequestIPMismatch() {
 void ArtNetNodeTest::testRDMRequestUIDMismatch() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
   SetupInputPort(&node);
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
@@ -2260,7 +2253,7 @@ void ArtNetNodeTest::testRDMRequestUIDMismatch() {
   }
 
   m_clock.AdvanceTime(3, 0);  // timeout is 2s
-  ss.RunOnce(0, 0);
+  ss.RunOnce();
   OLA_ASSERT(m_got_rdm_timeout);
 }
 
@@ -2271,7 +2264,7 @@ void ArtNetNodeTest::testRDMRequestUIDMismatch() {
 void ArtNetNodeTest::testTimeCode() {
   m_socket->SetDiscardMode(true);
   ArtNetNodeOptions node_options;
-  ArtNetNode node(interface, &ss, node_options, m_socket);
+  ArtNetNode node(iface, &ss, node_options, m_socket);
 
   OLA_ASSERT(node.Start());
   ss.RemoveReadDescriptor(m_socket);
