@@ -81,7 +81,7 @@ class DummyPort: public BasicOutputPort {
   /*
    * Handle an RDM Request
    */
-  void SendRDMRequest(const ola::rdm::RDMRequest *request,
+  void SendRDMRequest(ola::rdm::RDMRequest *request,
                       ola::rdm::RDMCallback *callback);
 
  private:
@@ -100,9 +100,7 @@ class DummyPort: public BasicOutputPort {
 
   void RunDiscovery(ola::rdm::RDMDiscoveryCallback *callback);
   void HandleBroadcastAck(broadcast_request_tracker *tracker,
-                          ola::rdm::rdm_response_code code,
-                          const ola::rdm::RDMResponse *response,
-                          const std::vector<std::string> &packets);
+                          ola::rdm::RDMReply *reply);
 
   // See http://www.opendmx.net/index.php/Open_Lighting_Allocations
   // Do not change.
