@@ -29,6 +29,7 @@
 #include <string>
 #include <vector>
 
+#include "common/rdm/TestHelper.h"
 #include "ola/Constants.h"
 #include "ola/Logging.h"
 #include "ola/network/NetworkUtils.h"
@@ -48,13 +49,13 @@ namespace dummy {
 using ola::network::HostToNetwork;
 using ola::rdm::RDMGetRequest;
 using ola::rdm::RDMGetResponse;
+using ola::rdm::RDMReply;
 using ola::rdm::RDMRequest;
 using ola::rdm::RDMResponse;
 using ola::rdm::RDMSetRequest;
 using ola::rdm::RDMSetResponse;
 using ola::rdm::UID;
 using ola::rdm::UIDSet;
-using ola::testing::ASSERT_DATA_EQUALS;
 using std::min;
 using std::string;
 using std::vector;
@@ -93,10 +94,8 @@ class DummyPortTest: public CppUnit::TestFixture {
     m_expected_response = NULL;
     m_got_uids = false;
   }
-  void HandleRDMResponse(ola::rdm::rdm_response_code code,
-                         const RDMResponse *response,
-                         const vector<string> &packets);
-  void SetExpectedResponse(ola::rdm::rdm_response_code code,
+  void HandleRDMResponse(RDMReply *reply);
+  void SetExpectedResponse(ola::rdm::RDMStatusCode code,
                            const RDMResponse *response);
   void Verify() { OLA_ASSERT_FALSE(m_expected_response); }
 
@@ -115,7 +114,7 @@ class DummyPortTest: public CppUnit::TestFixture {
   UID m_expected_uid;
   UID m_test_source;
   MockDummyPort m_port;
-  ola::rdm::rdm_response_code m_expected_code;
+  ola::rdm::RDMStatusCode m_expected_code;
   const RDMResponse *m_expected_response;
   bool m_got_uids;
 
@@ -159,26 +158,18 @@ class DummyPortTest: public CppUnit::TestFixture {
 CPPUNIT_TEST_SUITE_REGISTRATION(DummyPortTest);
 
 
-void DummyPortTest::HandleRDMResponse(ola::rdm::rdm_response_code code,
-                                      const ola::rdm::RDMResponse *response,
-                                      const vector<string>&) {
-  OLA_ASSERT_EQ(m_expected_code, code);
+void DummyPortTest::HandleRDMResponse(RDMReply *reply) {
+  OLA_ASSERT_EQ(m_expected_code, reply->StatusCode());
   if (m_expected_response) {
-    ASSERT_DATA_EQUALS(__LINE__,
-                       m_expected_response->ParamData(),
-                       m_expected_response->ParamDataSize(),
-                       response->ParamData(),
-                       response->ParamDataSize());
-    OLA_ASSERT(*m_expected_response == *response);
+    OLA_ASSERT_TRUE(*m_expected_response == *reply->Response());
   } else {
-    OLA_ASSERT_NULL(response);
+    OLA_ASSERT_NULL(reply->Response());
   }
-  delete response;
   delete m_expected_response;
   m_expected_response = NULL;
 }
 
-void DummyPortTest::SetExpectedResponse(ola::rdm::rdm_response_code code,
+void DummyPortTest::SetExpectedResponse(ola::rdm::RDMStatusCode code,
                                         const RDMResponse *response) {
   m_expected_code = code;
   m_expected_response = response;
@@ -205,7 +196,6 @@ void DummyPortTest::testUnknownPid() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_COMMS_STATUS,  // param id
       NULL,  // data
@@ -232,7 +222,6 @@ void DummyPortTest::testSupportedParams() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_SUPPORTED_PARAMETERS,  // param id
       NULL,  // data
@@ -297,7 +286,6 @@ void DummyPortTest::testDeviceInfo() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_DEVICE_INFO,  // param id
       NULL,  // data
@@ -351,7 +339,6 @@ void DummyPortTest::testSoftwareVersion() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_SOFTWARE_VERSION_LABEL,  // param id
       NULL,  // data
@@ -385,7 +372,6 @@ void DummyPortTest::testDmxAddress() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_DMX_START_ADDRESS,  // param id
       NULL,  // data
@@ -410,7 +396,6 @@ void DummyPortTest::testDmxAddress() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      2,  // message count
       0,  // sub device
       ola::rdm::PID_DMX_START_ADDRESS,  // param id
       reinterpret_cast<const uint8_t*>(&dmx_address),
@@ -429,7 +414,6 @@ void DummyPortTest::testDmxAddress() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_DMX_START_ADDRESS,  // param id
       NULL,  // data
@@ -455,7 +439,6 @@ void DummyPortTest::testDmxAddress() {
       broadcast_uid,
       0,  // transaction #
       1,  // port id
-      3,  // message count
       0,  // sub device
       ola::rdm::PID_DMX_START_ADDRESS,  // param id
       reinterpret_cast<const uint8_t*>(&dmx_address),
@@ -474,7 +457,6 @@ void DummyPortTest::testDmxAddress() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_DMX_START_ADDRESS,  // param id
       NULL,  // data
@@ -507,7 +489,6 @@ void DummyPortTest::testIdentifyDevice() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_IDENTIFY_DEVICE,  // param id
       NULL,  // data
@@ -532,7 +513,6 @@ void DummyPortTest::testIdentifyDevice() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      2,  // message count
       0,  // sub device
       ola::rdm::PID_IDENTIFY_DEVICE,  // param id
       &new_mode,
@@ -551,7 +531,6 @@ void DummyPortTest::testIdentifyDevice() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_IDENTIFY_DEVICE,  // param id
       NULL,  // data
@@ -577,7 +556,6 @@ void DummyPortTest::testIdentifyDevice() {
       broadcast_uid,
       0,  // transaction #
       1,  // port id
-      3,  // message count
       0,  // sub device
       ola::rdm::PID_IDENTIFY_DEVICE,  // param id
       &new_mode,
@@ -596,7 +574,6 @@ void DummyPortTest::testIdentifyDevice() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_IDENTIFY_DEVICE,  // param id
       NULL,  // data
@@ -631,7 +608,6 @@ void DummyPortTest::testParamDescription() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_PARAMETER_DESCRIPTION,  // param id
       reinterpret_cast<uint8_t*>(&param_id),  // data
@@ -697,7 +673,6 @@ void DummyPortTest::testParamDescription() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_PARAMETER_DESCRIPTION,  // param id
       reinterpret_cast<uint8_t*>(&unknown_param_id),  // data
@@ -728,7 +703,6 @@ void DummyPortTest::testOlaManufacturerPidCodeVersion() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::OLA_MANUFACTURER_PID_CODE_VERSION,  // param id
       NULL,  // data
@@ -762,7 +736,6 @@ void DummyPortTest::testSlotInfo() {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_SLOT_INFO,  // param id
       NULL,  // data
@@ -835,7 +808,6 @@ void DummyPortTest::checkSubDeviceOutOfRange(uint16_t pid) {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       1,  // sub device
       pid,
       NULL,  // data
@@ -861,7 +833,6 @@ void DummyPortTest::checkMalformedRequest(uint16_t pid,
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       pid,
       reinterpret_cast<uint8_t*>(&bad_data),  // data
@@ -885,7 +856,6 @@ void DummyPortTest::checkSetRequest(uint16_t pid) {
       m_expected_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       pid,
       NULL,  // data
@@ -910,7 +880,6 @@ void DummyPortTest::checkNoBroadcastResponse(uint16_t pid) {
       broadcast_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       pid,  // param id
       NULL,  // data
@@ -929,7 +898,6 @@ void DummyPortTest::checkNoBroadcastResponse(uint16_t pid) {
       broadcast_uid,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       pid,  // param id
       NULL,  // data
