@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * OSCDevice.h
  * The OSC Device.
@@ -55,6 +55,7 @@ class OSCDevice: public Device {
               const PortConfigs &port_configs);
     std::string DeviceId() const { return "1"; }
 
+    bool AllowLooping() const { return true; }
     bool AllowMultiPortPatching() const { return true; }
 
  protected:
