@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * PathportDevice.cpp
  * Pathport device
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #include <sstream>
@@ -35,7 +35,7 @@ namespace ola {
 namespace plugin {
 namespace pathport {
 
-using std::stringstream;
+using std::ostringstream;
 using std::vector;
 
 const char PathportDevice::K_DEFAULT_NODE_NAME[] = "ola-Pathport";
@@ -90,7 +90,7 @@ bool PathportDevice::StartHook() {
     return false;
   }
 
-  stringstream str;
+  ostringstream str;
   str << PATHPORT_DEVICE_NAME << " [" << m_node->GetInterface().ip_address <<
     "]";
   SetName(str.str());
