@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * SandNetDevice.cpp
  * SandNet device
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #include <sstream>
@@ -35,8 +35,8 @@ namespace ola {
 namespace plugin {
 namespace sandnet {
 
+using std::ostringstream;
 using std::string;
-using std::stringstream;
 using std::vector;
 
 const char SandNetDevice::IP_KEY[] = "ip";
@@ -87,7 +87,7 @@ bool SandNetDevice::StartHook() {
     return false;
   }
 
-  stringstream str;
+  ostringstream str;
   str << SANDNET_DEVICE_NAME << " [" << m_node->GetInterface().ip_address <<
     "]";
   SetName(str.str());
