@@ -231,10 +231,11 @@ void SPIDevice::SetDefaults() {
                                  SetValidator<string>(valid_backends),
                                  SOFTWARE_BACKEND);
   m_preferences->SetDefaultValue(SPISpeedKey(), UIntValidator(0, 32000000),
-                                 "1000000");
-  m_preferences->SetDefaultValue(SPICEKey(), BoolValidator(), "false");
-  m_preferences->SetDefaultValue(PortCountKey(), UIntValidator(1, 8), "1");
-  m_preferences->SetDefaultValue(SyncPortKey(), IntValidator(-2, 8), "0");
+                                 1000000);
+  m_preferences->SetDefaultValue(SPICEKey(), BoolValidator(), false);
+  m_preferences->SetDefaultValue(PortCountKey(), UIntValidator(1, 8), 1);
+  m_preferences->SetDefaultValue(SyncPortKey(), IntValidator(-2, 8), 0);
+  m_preferences->Save();
 }
 
 void SPIDevice::PopulateHardwareBackendOptions(
@@ -260,8 +261,15 @@ void SPIDevice::PopulateHardwareBackendOptions(
 
 void SPIDevice::PopulateSoftwareBackendOptions(
     SoftwareBackend::Options *options) {
-  StringToInt(m_preferences->GetValue(PortCountKey()), &options->outputs);
-  StringToInt(m_preferences->GetValue(SyncPortKey()), &options->sync_output);
+  if (!StringToInt(m_preferences->GetValue(PortCountKey()),
+                                           &options->outputs)) {
+    OLA_WARN << "Invalid integer value for " << PortCountKey();
+  }
+
+  if (!StringToInt(m_preferences->GetValue(SyncPortKey()),
+                                           &options->sync_output)) {
+    OLA_WARN << "Invalid integer value for " << SyncPortKey();
+  }
   if (options->sync_output == -2) {
     options->sync_output = options->outputs - 1;
   }
