@@ -50,6 +50,7 @@ BaseUsbProWidget::BaseUsbProWidget(
     : m_descriptor(descriptor),
       m_state(PRE_SOM),
       m_bytes_received(0) {
+  memset(&m_header, 0, sizeof(m_header));
   m_descriptor->SetOnData(
       NewCallback(this, &BaseUsbProWidget::DescriptorReady));
 }
@@ -126,7 +127,7 @@ ola::io::ConnectedDescriptor *BaseUsbProWidget::OpenDevice(
     const string &path) {
   struct termios newtio;
   int fd;
-  if (!ola::io::Open(path, O_RDWR | O_NONBLOCK | O_NOCTTY, &fd)) {
+  if (!ola::io::TryOpen(path, O_RDWR | O_NONBLOCK | O_NOCTTY, &fd)) {
     return NULL;
   }
 
@@ -155,16 +156,19 @@ void BaseUsbProWidget::ReceiveMessage() {
           return;
       } while (m_header.som != SOM);
       m_state = RECV_LABEL;
+      // fall through
     case RECV_LABEL:
       m_descriptor->Receive(&m_header.label, 1, count);
       if (count != 1)
         return;
       m_state = RECV_SIZE_LO;
+      // fall through
     case RECV_SIZE_LO:
       m_descriptor->Receive(&m_header.len, 1, count);
       if (count != 1)
         return;
       m_state = RECV_SIZE_HI;
+      // fall through
     case RECV_SIZE_HI:
       m_descriptor->Receive(&m_header.len_hi, 1, count);
       if (count != 1)
@@ -181,6 +185,7 @@ void BaseUsbProWidget::ReceiveMessage() {
 
       m_bytes_received = 0;
       m_state = RECV_BODY;
+      // fall through
     case RECV_BODY:
       packet_length = (m_header.len_hi << 8) + m_header.len;
       m_descriptor->Receive(
@@ -196,6 +201,7 @@ void BaseUsbProWidget::ReceiveMessage() {
         return;
 
       m_state = RECV_EOM;
+      // fall through
     case RECV_EOM:
       // check this is a valid frame with an end byte
       uint8_t eom;
