@@ -23,6 +23,7 @@
 #include <string>
 #include <vector>
 
+#include "common/rdm/TestHelper.h"
 #include "ola/Callback.h"
 #include "ola/DmxBuffer.h"
 #include "ola/Logging.h"
@@ -37,6 +38,7 @@ using ola::NewSingleCallback;
 using ola::plugin::usbpro::DmxTriWidget;
 using ola::rdm::NewDiscoveryUniqueBranchRequest;
 using ola::rdm::RDMDiscoveryRequest;
+using ola::rdm::RDMReply;
 using ola::rdm::RDMRequest;
 using ola::rdm::RDMResponse;
 using ola::rdm::UID;
@@ -87,24 +89,18 @@ class DmxTriWidgetTest: public CommonWidgetTest {
     void AckSingleTxAndExpectData();
     void PopulateTod();
     void ValidateTod(const ola::rdm::UIDSet &uids);
-    void ValidateResponse(ola::rdm::rdm_response_code expected_code,
+    void ValidateResponse(ola::rdm::RDMStatusCode expected_code,
                           const RDMResponse *expected_response,
-                          vector<string> expected_packets,
-                          ola::rdm::rdm_response_code code,
-                          const RDMResponse *response,
-                          const vector<string> &packets);
-    void ValidateStatus(ola::rdm::rdm_response_code expected_code,
-                        vector<string> expected_packets,
-                        ola::rdm::rdm_response_code code,
-                        const RDMResponse *response,
-                        const vector<string> &packets);
-    const RDMRequest *NewRequest(const UID &source,
-                                 const UID &destination,
-                                 const uint8_t *data,
-                                 unsigned int length);
-    const RDMRequest *NewQueuedMessageRequest(const UID &source,
-                                              const UID &destination,
-                                              uint8_t code);
+                          RDMReply *reply);
+    void ValidateStatus(ola::rdm::RDMStatusCode expected_code,
+                        RDMReply *reply);
+    RDMRequest *NewRequest(const UID &source,
+                           const UID &destination,
+                           const uint8_t *data,
+                           unsigned int length);
+    RDMRequest *NewQueuedMessageRequest(const UID &source,
+                                        const UID &destination,
+                                        uint8_t code);
 
     static const uint8_t EXTENDED_LABEL = 0x58;
 };
@@ -143,37 +139,30 @@ void DmxTriWidgetTest::ValidateTod(const ola::rdm::UIDSet &uids) {
  * Check the response matches what we expected.
  */
 void DmxTriWidgetTest::ValidateResponse(
-    ola::rdm::rdm_response_code expected_code,
+    ola::rdm::RDMStatusCode expected_code,
     const RDMResponse *expected_response,
-    vector<string> expected_packets,
-    ola::rdm::rdm_response_code code,
-    const RDMResponse *response,
-    const vector<string> &packets) {
-  OLA_ASSERT_EQ(expected_code, code);
-  OLA_ASSERT(response);
-  OLA_ASSERT(*expected_response == *response);
-  delete response;
+    RDMReply *reply) {
+  OLA_ASSERT_EQ(expected_code, reply->StatusCode());
+  OLA_ASSERT(reply->Response());
+  OLA_ASSERT_TRUE(*expected_response == *reply->Response());
 
   // the TRIs can't return the actual packets
-  OLA_ASSERT_EQ(expected_packets.size(), packets.size());
+  OLA_ASSERT_EMPTY(reply->Frames());
   m_ss.Terminate();
 }
 
 
 /*
- * Check that we got an unknown UID code
+ * Check that we received the correct status code.
  */
 void DmxTriWidgetTest::ValidateStatus(
-    ola::rdm::rdm_response_code expected_code,
-    vector<string> expected_packets,
-    ola::rdm::rdm_response_code code,
-    const RDMResponse *response,
-    const vector<string> &packets) {
-  OLA_ASSERT_EQ(expected_code, code);
-  OLA_ASSERT_FALSE(response);
+    ola::rdm::RDMStatusCode expected_code,
+    RDMReply *reply) {
+  OLA_ASSERT_EQ(expected_code, reply->StatusCode());
+  OLA_ASSERT_NULL(reply->Response());
 
   // the TRIs can't return the actual packets
-  OLA_ASSERT_EQ(expected_packets.size(), packets.size());
+  OLA_ASSERT_EMPTY(reply->Frames());
   m_ss.Terminate();
 }
 
@@ -181,16 +170,15 @@ void DmxTriWidgetTest::ValidateStatus(
 /**
  * Helper method to create new request objects
  */
-const RDMRequest *DmxTriWidgetTest::NewRequest(const UID &source,
-                                               const UID &destination,
-                                               const uint8_t *data,
-                                               unsigned int length) {
+RDMRequest *DmxTriWidgetTest::NewRequest(const UID &source,
+                                         const UID &destination,
+                                         const uint8_t *data,
+                                         unsigned int length) {
   return new ola::rdm::RDMGetRequest(
       source,
       destination,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       10,  // sub device
       296,  // param id
       data,
@@ -201,7 +189,7 @@ const RDMRequest *DmxTriWidgetTest::NewRequest(const UID &source,
 /**
  * Helper method to create a new queued request object
  */
-const RDMRequest *DmxTriWidgetTest::NewQueuedMessageRequest(
+RDMRequest *DmxTriWidgetTest::NewQueuedMessageRequest(
     const UID &source,
     const UID &destination,
     uint8_t code) {
@@ -210,7 +198,6 @@ const RDMRequest *DmxTriWidgetTest::NewQueuedMessageRequest(
       destination,
       0,  // transaction #
       1,  // port id
-      0,  // message count
       10,  // sub device
       ola::rdm::PID_QUEUED_MESSAGE,
       &code,
@@ -450,20 +437,18 @@ void DmxTriWidgetTest::testSendRDM() {
   UID destination(0x707a, 0xffffff00);
   uint8_t param_data[] = {0xa1, 0xb2};
 
-  const RDMRequest *request = NewRequest(
+  RDMRequest *request = NewRequest(
       source,
       destination,
       param_data,
       sizeof(param_data));
 
   // first of all confirm we can't send to a UID not in the TOD
-  vector<string> packets;
   m_widget->SendRDMRequest(
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_UNKNOWN_UID,
-                        packets));
+                        ola::rdm::RDM_UNKNOWN_UID));
 
   // now populate the TOD
   PopulateTod();
@@ -503,8 +488,7 @@ void DmxTriWidgetTest::testSendRDM() {
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateResponse,
                         ola::rdm::RDM_COMPLETED_OK,
-                        static_cast<const RDMResponse*>(&response),
-                        packets));
+                        static_cast<const RDMResponse*>(&response)));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -541,8 +525,7 @@ void DmxTriWidgetTest::testSendRDM() {
         this,
         &DmxTriWidgetTest::ValidateResponse,
         ola::rdm::RDM_COMPLETED_OK,
-        static_cast<const RDMResponse*>(&response2),
-        packets));
+        static_cast<const RDMResponse*>(&response2)));
   m_ss.Run();
   m_endpoint->Verify();
 }
@@ -556,12 +539,11 @@ void DmxTriWidgetTest::testSendRDMErrors() {
 
   // populate the TOD
   PopulateTod();
-  vector<string> packets;
 
   uint8_t expected_rdm_command[] = {0x38, 0x02, 0x00, 0x0a, 0x01, 0x28};
 
   // confirm transaction mis-match works
-  const RDMRequest *request = NewRequest(source, destination, NULL, 0);
+  RDMRequest *request = NewRequest(source, destination, NULL, 0);
 
   uint8_t transaction_mismatch_response[] = {0x38, 0x13};
   m_endpoint->AddExpectedUsbProDataAndReturn(
@@ -576,8 +558,7 @@ void DmxTriWidgetTest::testSendRDMErrors() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_TRANSACTION_MISMATCH,
-                        packets));
+                        ola::rdm::RDM_TRANSACTION_MISMATCH));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -597,8 +578,7 @@ void DmxTriWidgetTest::testSendRDMErrors() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_SUB_DEVICE_MISMATCH,
-                        packets));
+                        ola::rdm::RDM_SUB_DEVICE_MISMATCH));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -618,8 +598,7 @@ void DmxTriWidgetTest::testSendRDMErrors() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_INVALID_RESPONSE,
-                        packets));
+                        ola::rdm::RDM_INVALID_RESPONSE));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -639,8 +618,7 @@ void DmxTriWidgetTest::testSendRDMErrors() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_CHECKSUM_INCORRECT,
-                        packets));
+                        ola::rdm::RDM_CHECKSUM_INCORRECT));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -660,8 +638,7 @@ void DmxTriWidgetTest::testSendRDMErrors() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_TIMEOUT,
-                        packets));
+                        ola::rdm::RDM_TIMEOUT));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -681,8 +658,7 @@ void DmxTriWidgetTest::testSendRDMErrors() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_SRC_UID_MISMATCH,
-                        packets));
+                        ola::rdm::RDM_SRC_UID_MISMATCH));
   m_ss.Run();
   m_endpoint->Verify();
 }
@@ -695,10 +671,9 @@ void DmxTriWidgetTest::testSendRDMBroadcast() {
   UID vendor_cast_destination(0x707a, 0xffffffff);
   UID bcast_destination(0xffff, 0xffffffff);
 
-  vector<string> packets;
   PopulateTod();
 
-  const RDMRequest *request = NewRequest(
+  RDMRequest *request = NewRequest(
       source,
       vendor_cast_destination,
       NULL,
@@ -728,8 +703,7 @@ void DmxTriWidgetTest::testSendRDMBroadcast() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_WAS_BROADCAST,
-                        packets));
+                        ola::rdm::RDM_WAS_BROADCAST));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -757,8 +731,7 @@ void DmxTriWidgetTest::testSendRDMBroadcast() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_WAS_BROADCAST,
-                        packets));
+                        ola::rdm::RDM_WAS_BROADCAST));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -777,8 +750,7 @@ void DmxTriWidgetTest::testSendRDMBroadcast() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_WAS_BROADCAST,
-                        packets));
+                        ola::rdm::RDM_WAS_BROADCAST));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -798,8 +770,7 @@ void DmxTriWidgetTest::testSendRDMBroadcast() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_FAILED_TO_SEND,
-                        packets));
+                        ola::rdm::RDM_FAILED_TO_SEND));
   m_ss.Run();
   m_endpoint->Verify();
 }
@@ -813,7 +784,6 @@ void DmxTriWidgetTest::testRawDiscovery() {
   UID lower(0, 0);
   UID upper(0xffff, 0xfffffff);
 
-  vector<string> packets;
   PopulateTod();
 
   RDMDiscoveryRequest *dub_request = NewDiscoveryUniqueBranchRequest(
@@ -824,8 +794,7 @@ void DmxTriWidgetTest::testRawDiscovery() {
       dub_request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_PLUGIN_DISCOVERY_NOT_SUPPORTED,
-                        packets));
+                        ola::rdm::RDM_PLUGIN_DISCOVERY_NOT_SUPPORTED));
   m_endpoint->Verify();
 }
 
@@ -837,10 +806,9 @@ void DmxTriWidgetTest::testNack() {
   UID source(1, 2);
   UID destination(0x707a, 0xffffff00);
 
-  vector<string> packets;
   PopulateTod();
 
-  const RDMRequest *request = NewRequest(source, destination, NULL, 0);
+  RDMRequest *request = NewRequest(source, destination, NULL, 0);
 
   uint8_t expected_rdm_command[] = {0x38, 0x02, 0x00, 0x0a, 0x01, 0x28};
   uint8_t nack_pid_response[] = {0x38, 0x20};  // unknown pid
@@ -861,8 +829,7 @@ void DmxTriWidgetTest::testNack() {
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateResponse,
                         ola::rdm::RDM_COMPLETED_OK,
-                        static_cast<const RDMResponse*>(response),
-                        packets));
+                        static_cast<const RDMResponse*>(response)));
   m_ss.Run();
   m_endpoint->Verify();
   delete response;
@@ -888,8 +855,7 @@ void DmxTriWidgetTest::testNack() {
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateResponse,
                         ola::rdm::RDM_COMPLETED_OK,
-                        static_cast<const RDMResponse*>(response),
-                        packets));
+                        static_cast<const RDMResponse*>(response)));
   m_ss.Run();
   m_endpoint->Verify();
   delete response;
@@ -903,10 +869,9 @@ void DmxTriWidgetTest::testAckTimer() {
   UID source(1, 2);
   UID destination(0x707a, 0xffffff00);
 
-  vector<string> packets;
   PopulateTod();
 
-  const RDMRequest *request = NewRequest(source, destination, NULL, 0);
+  RDMRequest *request = NewRequest(source, destination, NULL, 0);
 
   uint8_t expected_rdm_command[] = {0x38, 0x02, 0x00, 0x0a, 0x01, 0x28};
   uint8_t ack_timer_response[] = {0x38, 0x10, 0x00, 0x10};  // ack timer, 1.6s
@@ -936,8 +901,7 @@ void DmxTriWidgetTest::testAckTimer() {
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateResponse,
                         ola::rdm::RDM_COMPLETED_OK,
-                        static_cast<const RDMResponse*>(&response),
-                        packets));
+                        static_cast<const RDMResponse*>(&response)));
   m_ss.Run();
   m_endpoint->Verify();
 }
@@ -950,10 +914,9 @@ void DmxTriWidgetTest::testAckOverflow() {
   UID source(1, 2);
   UID destination(0x707a, 0xffffff00);
 
-  vector<string> packets;
   PopulateTod();
 
-  const RDMRequest *request = NewRequest(source, destination, NULL, 0);
+  RDMRequest *request = NewRequest(source, destination, NULL, 0);
 
   uint8_t expected_rdm_command[] = {0x38, 0x02, 0x00, 0x0a, 0x01, 0x28};
   uint8_t ack_overflow_response[] = {0x38, 0x12, 0x12, 0x34};  // ack overflow
@@ -992,8 +955,7 @@ void DmxTriWidgetTest::testAckOverflow() {
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateResponse,
                         ola::rdm::RDM_COMPLETED_OK,
-                        static_cast<const RDMResponse*>(&response),
-                        packets));
+                        static_cast<const RDMResponse*>(&response)));
   m_ss.Run();
   m_endpoint->Verify();
 }
@@ -1004,11 +966,10 @@ void DmxTriWidgetTest::testAckOverflow() {
 void DmxTriWidgetTest::testQueuedMessages() {
   UID source(1, 2);
   UID destination(0x707a, 0xffffff00);
-  vector<string> packets;
   PopulateTod();
 
   // first try a response which is too short
-  const RDMRequest *request = NewQueuedMessageRequest(source, destination, 1);
+  RDMRequest *request = NewQueuedMessageRequest(source, destination, 1);
   uint8_t expected_rdm_command[] = {0x3a, 0x02, 0x01};
   uint8_t small_response[] = {0x3a, 0x04};
   m_endpoint->AddExpectedUsbProDataAndReturn(
@@ -1023,8 +984,7 @@ void DmxTriWidgetTest::testQueuedMessages() {
       request,
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateStatus,
-                        ola::rdm::RDM_INVALID_RESPONSE,
-                        packets));
+                        ola::rdm::RDM_INVALID_RESPONSE));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -1056,8 +1016,7 @@ void DmxTriWidgetTest::testQueuedMessages() {
       NewSingleCallback(this,
                         &DmxTriWidgetTest::ValidateResponse,
                         ola::rdm::RDM_COMPLETED_OK,
-                        static_cast<const RDMResponse*>(&response),
-                        packets));
+                        static_cast<const RDMResponse*>(&response)));
   m_ss.Run();
   m_endpoint->Verify();
 }
