@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * EnttecUsbProWidgetTest.cpp
  * Test fixture for the EnttecUsbProWidget class
@@ -23,9 +23,11 @@
 #include <string>
 #include <vector>
 
+#include "common/rdm/TestHelper.h"
 #include "ola/Callback.h"
 #include "ola/DmxBuffer.h"
 #include "ola/Logging.h"
+#include "ola/base/Array.h"
 #include "ola/rdm/RDMCommandSerializer.h"
 #include "ola/rdm/UID.h"
 #include "ola/testing/TestUtils.h"
@@ -39,6 +41,9 @@ using ola::plugin::usbpro::EnttecUsbProWidget;
 using ola::rdm::GetResponseFromData;
 using ola::rdm::RDMCommandSerializer;
 using ola::rdm::RDMDiscoveryRequest;
+using ola::rdm::RDMFrame;
+using ola::rdm::RDMFrames;
+using ola::rdm::RDMReply;
 using ola::rdm::RDMRequest;
 using ola::rdm::RDMResponse;
 using ola::rdm::UID;
@@ -78,21 +83,17 @@ class EnttecUsbProWidgetTest: public CommonWidgetTest {
  private:
     auto_ptr<EnttecUsbProWidget> m_widget;
     uint8_t m_transaction_number;
-    ola::rdm::rdm_response_code m_received_code;
+    ola::rdm::RDMStatusCode m_received_code;
 
-    const RDMRequest *NewRequest(const UID &destination,
-                                 const uint8_t *data = NULL,
-                                 unsigned int length = 0);
+    RDMRequest *NewRequest(const UID &destination,
+                           const uint8_t *data = NULL,
+                           unsigned int length = 0);
     uint8_t *PackRDMRequest(const RDMRequest *request, unsigned int *size);
     uint8_t *PackRDMResponse(const RDMResponse *response, unsigned int *size);
-    void ValidateResponse(ola::rdm::rdm_response_code code,
-                          const ola::rdm::RDMResponse *response,
-                          const vector<string> &packets);
-    void ValidateStatus(ola::rdm::rdm_response_code expected_code,
-                        vector<string> expected_packets,
-                        ola::rdm::rdm_response_code code,
-                        const ola::rdm::RDMResponse *response,
-                        const vector<string> &packets);
+    void ValidateResponse(RDMReply *reply);
+    void ValidateStatus(ola::rdm::RDMStatusCode expected_code,
+                        RDMFrames expected_frames,
+                        RDMReply *reply);
     void ValidateMuteStatus(bool expected,
                             bool actual);
     void ValidateBranchStatus(const uint8_t *expected_data,
@@ -142,7 +143,7 @@ void EnttecUsbProWidgetTest::setUp() {
   EnttecUsbProWidget::EnttecUsbProWidgetOptions options(
       EnttecUsbProWidget::ENTTEC_ESTA_ID, 1);
   options.enable_rdm = true;
-  m_widget.reset(new EnttecUsbProWidget(&m_descriptor, options));
+  m_widget.reset(new EnttecUsbProWidget(&m_ss, &m_descriptor, options));
 
   m_transaction_number = 0;
   m_got_dmx = false;
@@ -155,15 +156,14 @@ void EnttecUsbProWidgetTest::setUp() {
  * @param data the RDM Request data
  * @param length the size of the RDM data.
  */
-const RDMRequest *EnttecUsbProWidgetTest::NewRequest(const UID &destination,
-                                                     const uint8_t *data,
-                                                     unsigned int length) {
+RDMRequest *EnttecUsbProWidgetTest::NewRequest(const UID &destination,
+                                               const uint8_t *data,
+                                               unsigned int length) {
   return new ola::rdm::RDMGetRequest(
       SOURCE,
       destination,
       m_transaction_number++,  // transaction #
       1,  // port id
-      0,  // message count
       10,  // sub device
       296,  // param id
       data,
@@ -206,58 +206,43 @@ uint8_t *EnttecUsbProWidgetTest::PackRDMResponse(const RDMResponse *response,
 /*
  * Check the response matches what we expected.
  */
-void EnttecUsbProWidgetTest::ValidateResponse(
-    ola::rdm::rdm_response_code code,
-    const ola::rdm::RDMResponse *response,
-    const vector<string> &packets) {
-  OLA_ASSERT_EQ(ola::rdm::RDM_COMPLETED_OK, code);
-  OLA_ASSERT(response);
-  OLA_ASSERT_EQ(
-      static_cast<unsigned int>(sizeof(TEST_RDM_DATA)),
-      response->ParamDataSize());
-  OLA_ASSERT(0 == memcmp(TEST_RDM_DATA, response->ParamData(),
-                             response->ParamDataSize()));
+void EnttecUsbProWidgetTest::ValidateResponse(RDMReply *reply) {
+  OLA_ASSERT_EQ(ola::rdm::RDM_COMPLETED_OK, reply->StatusCode());
+  OLA_ASSERT(reply->Response());
+  OLA_ASSERT_DATA_EQUALS(TEST_RDM_DATA, arraysize(TEST_RDM_DATA),
+                         reply->Response()->ParamData(),
+                         reply->Response()->ParamDataSize());
 
-  OLA_ASSERT_EQ((size_t) 1, packets.size());
-  ola::rdm::rdm_response_code raw_code;
+  const RDMFrames &frames = reply->Frames();
+  OLA_ASSERT_EQ((size_t) 1, frames.size());
+  ola::rdm::RDMStatusCode raw_code;
   auto_ptr<ola::rdm::RDMResponse> raw_response(
-    ola::rdm::RDMResponse::InflateFromData(packets[0], &raw_code));
-  OLA_ASSERT(*(raw_response.get()) == *response);
-  delete response;
+    ola::rdm::RDMResponse::InflateFromData(frames[0].data.data() + 1,
+                                           frames[0].data.size() - 1,
+                                           &raw_code));
+  OLA_ASSERT_TRUE(*raw_response.get() == *reply->Response());
   m_ss.Terminate();
 }
 
 
 /*
  * Check that this request returned the expected status code
- * @param expected_code the expected widget status code
- * @param expected_code a list of expected packets
- * @param code the actual status code returns
- * @param response the RDMResponse object, or NULL
- * @param packets the actual packets involved
  */
 void EnttecUsbProWidgetTest::ValidateStatus(
-    ola::rdm::rdm_response_code expected_code,
-    vector<string> expected_packets,
-    ola::rdm::rdm_response_code code,
-    const ola::rdm::RDMResponse *response,
-    const vector<string> &packets) {
-  OLA_ASSERT_EQ(expected_code, code);
-  OLA_ASSERT_FALSE(response);
+    ola::rdm::RDMStatusCode expected_code,
+    RDMFrames expected_frames,
+    RDMReply *reply) {
+  OLA_ASSERT_EQ(expected_code, reply->StatusCode());
+  OLA_ASSERT_FALSE(reply->Response());
 
-  OLA_ASSERT_EQ(expected_packets.size(), packets.size());
-  for (unsigned int i = 0; i < packets.size(); i++) {
-    if (expected_packets[i].size() != packets[i].size())
-      OLA_INFO << expected_packets[i].size() << " != " << packets[i].size();
-    OLA_ASSERT_EQ(expected_packets[i].size(), packets[i].size());
-
-    if (expected_packets[i] != packets[i]) {
-      for (unsigned int j = 0; j < packets[i].size(); j++) {
-        OLA_INFO << std::hex << static_cast<int>(packets[i][j]) << " - " <<
-          static_cast<int>(expected_packets[i][j]);
-      }
-    }
-    OLA_ASSERT(expected_packets[i] == packets[i]);
+  const RDMFrames &frames = reply->Frames();
+  OLA_ASSERT_EQ(expected_frames.size(), frames.size());
+  for (unsigned int i = 0; i < frames.size(); i++) {
+    OLA_ASSERT_DATA_EQUALS(expected_frames[i].data.data(),
+                           expected_frames[i].data.size(),
+                           frames[i].data.data(),
+                           frames[i].data.size());
+    OLA_ASSERT_TRUE(expected_frames[i] == frames[i]);
   }
   m_received_code = expected_code;
   m_ss.Terminate();
@@ -494,7 +479,7 @@ void EnttecUsbProWidgetTest::testSendRDMRequest() {
   OLA_ASSERT_NOT_NULL(port);
 
   // request
-  const RDMRequest *rdm_request = NewRequest(DESTINATION);
+  RDMRequest *rdm_request = NewRequest(DESTINATION);
   unsigned int expected_request_frame_size;
   uint8_t *expected_request_frame = PackRDMRequest(
       rdm_request,
@@ -540,14 +525,14 @@ void EnttecUsbProWidgetTest::testSendRDMRequest() {
       NULL,
       0);
 
-  vector<string> packets;
+  RDMFrames frames;
   m_received_code = ola::rdm::RDM_COMPLETED_OK;
   port->SendRDMRequest(
       rdm_request,
       ola::NewSingleCallback(this,
                              &EnttecUsbProWidgetTest::ValidateStatus,
                              ola::rdm::RDM_WAS_BROADCAST,
-                             packets));
+                             frames));
   m_ss.Run();
   OLA_ASSERT_EQ(ola::rdm::RDM_WAS_BROADCAST, m_received_code);
   m_endpoint->Verify();
@@ -565,12 +550,11 @@ void EnttecUsbProWidgetTest::testSendRDMMute() {
   OLA_ASSERT_NOT_NULL(port);
 
   // request
-  const RDMRequest *rdm_request = new ola::rdm::RDMDiscoveryRequest(
+  RDMRequest *rdm_request = new ola::rdm::RDMDiscoveryRequest(
       SOURCE,
       DESTINATION,
       m_transaction_number++,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_DISC_MUTE,  // param id
       NULL,
@@ -620,12 +604,11 @@ void EnttecUsbProWidgetTest::testSendRDMDUB() {
   };
 
   // request
-  const RDMRequest *rdm_request = new ola::rdm::RDMDiscoveryRequest(
+  RDMRequest *rdm_request = new ola::rdm::RDMDiscoveryRequest(
       SOURCE,
       DESTINATION,
       m_transaction_number++,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_DISC_UNIQUE_BRANCH,  // param id
       REQUEST_DATA,
@@ -647,13 +630,13 @@ void EnttecUsbProWidgetTest::testSendRDMDUB() {
       EMPTY_RESPONSE,
       sizeof(EMPTY_RESPONSE));
 
-  vector<string> packets;
+  RDMFrames frames;
   port->SendRDMRequest(
       rdm_request,
       ola::NewSingleCallback(this,
                              &EnttecUsbProWidgetTest::ValidateStatus,
                              ola::rdm::RDM_TIMEOUT,
-                             packets));
+                             frames));
   m_ss.Run();
   m_endpoint->Verify();
 
@@ -665,7 +648,6 @@ void EnttecUsbProWidgetTest::testSendRDMDUB() {
       DESTINATION,
       m_transaction_number++,  // transaction #
       1,  // port id
-      0,  // message count
       0,  // sub device
       ola::rdm::PID_DISC_UNIQUE_BRANCH,  // param id
       REQUEST_DATA,
@@ -686,15 +668,13 @@ void EnttecUsbProWidgetTest::testSendRDMDUB() {
       FAKE_RESPONSE,
       sizeof(FAKE_RESPONSE));
 
-  packets.push_back(
-      string(reinterpret_cast<const char*>(&FAKE_RESPONSE[1]),
-             sizeof(FAKE_RESPONSE) - 1));
+  frames.push_back(RDMFrame(FAKE_RESPONSE + 1, arraysize(FAKE_RESPONSE) - 1));
   port->SendRDMRequest(
       rdm_request,
       ola::NewSingleCallback(this,
                              &EnttecUsbProWidgetTest::ValidateStatus,
                              ola::rdm::RDM_DUB_RESPONSE,
-                             packets));
+                             frames));
   m_ss.Run();
   m_endpoint->Verify();
 
