@@ -87,8 +87,8 @@ string UsbSerialPlugin::Description() const {
 " - Arduino RGB Mixer\n"
 " - DMX-TRI & RDM-TRI\n"
 " - DMXking USB DMX512-A, Ultra DMX, Ultra DMX Pro\n"
-" - DMXter4 & mini DMXter\n"
-" - Enttec DMX USB Pro\n"
+" - DMXter4, DMXter4A & mini DMXter\n"
+" - Enttec DMX USB Pro & USB Pro Mk II\n"
 " - Robe Universe Interface\n"
 "\n"
 "See http://opendmx.net/index.php/USB_Protocol_Extensions for more info.\n"
