@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -21,14 +21,14 @@
 __author__ = 'nomis52@gmail.com (Simon Newton)'
 
 from ola.ClientWrapper import ClientWrapper
-from ola import ArtnetConfigMessages_pb2
+from ola import ArtNetConfigMessages_pb2
 
 def ArtNetConfigureReply(state, response):
-  reply = ArtnetConfigMessages_pb2.Reply()
+  reply = ArtNetConfigMessages_pb2.Reply()
   reply.ParseFromString(response)
-  print 'Short Name: %s' % reply.options.short_name
-  print 'Long Name: %s' % reply.options.long_name
-  print 'Subnet: %d' % reply.options.subnet
+  print('Short Name: %s' % reply.options.short_name)
+  print('Long Name: %s' % reply.options.long_name)
+  print('Subnet: %d' % reply.options.subnet)
   wrapper.Stop()
 
 
@@ -36,7 +36,7 @@ def ArtNetConfigureReply(state, response):
 device_alias = 1
 wrapper = ClientWrapper()
 client = wrapper.Client()
-artnet_request = ArtnetConfigMessages_pb2.Request()
+artnet_request = ArtNetConfigMessages_pb2.Request()
 artnet_request.type = artnet_request.ARTNET_OPTIONS_REQUEST
 client.ConfigureDevice(device_alias, artnet_request.SerializeToString(),
                        ArtNetConfigureReply)
