@@ -61,6 +61,19 @@ class UID(object):
       return cmp(self._device_id, other._device_id)
     return cmp(self.manufacturer_id, other.manufacturer_id)
 
+  def __lt__(self, other):
+    if self.manufacturer_id != other.manufacturer_id:
+      return self.manufacturer_id < other.manufacturer_id
+    else:
+      return self.device_id < other.device_id
+
+  def __eq__(self, other):
+    if other is None:
+      return False
+
+    return self.manufacturer_id == other.manufacturer_id and \
+           self.device_id == other.device_id
+
   @staticmethod
   def AllDevices():
     return UID(0xffff, 0xffffffff)
