@@ -43,7 +43,10 @@ class EndpointManager {
     typedef ola::Callback1<void, uint16_t> EndpointNotificationCallback;
     typedef enum { ADD, REMOVE, BOTH } EndpointNoticationEvent;
 
-    EndpointManager() {}
+    EndpointManager()
+        : m_list_change_number(0) {
+    }
+
     ~EndpointManager() {}
 
     uint32_t list_change_number() const { return m_list_change_number; }
