@@ -16,14 +16,15 @@
  * e133-receiver.cpp
  * Copyright (C) 2011 Simon Newton
  *
- * This creates a E1.33 receiver with one (emulated) RDM responder. The node is
- * registered in slp and the RDM responder responds to E1.33 commands.
+ * This creates a E1.33 receiver with one (emulated) RDM responder. The node's
+ * RDM responder responds to E1.33 commands.
  */
 
 #if HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <signal.h>
 
 #include <ola/acn/ACNPort.h>
@@ -83,10 +84,12 @@ SimpleE133Node *simple_node;
 /*
  * Terminate cleanly on interrupt.
  */
-static void InteruptSignal(int signo) {
-  if (simple_node)
+static void InteruptSignal(OLA_UNUSED int signo) {
+  int old_errno = errno;
+  if (simple_node) {
     simple_node->Stop();
-  (void) signo;
+  }
+  errno = old_errno;
 }
 
 void HandleTriDMX(DmxBuffer *buffer, DmxTriWidget *widget) {
