@@ -11,7 +11,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # ola_rdm_get.py
 # Copyright (C) 2010 Simon Newton
@@ -253,16 +253,17 @@ def main():
     test_filter = set(options.tests.split(','))
 
   logging.info(
-      'Starting tests, universe %d, UID %s, broadcast write delay %dms' %
-      (options.universe, options.uid, options.broadcast_write_delay))
+      'Starting tests, universe %d, UID %s, broadcast write delay %dms, '
+      'inter-test delay %dms' % (options.universe, options.uid,
+      options.broadcast_write_delay, options.inter_test_delay))
 
   runner = TestRunner.TestRunner(options.universe,
                                  options.uid,
                                  options.broadcast_write_delay,
+                                 options.inter_test_delay,
                                  pid_store,
                                  wrapper,
-                                 options.timestamp,
-                                 options.inter_test_delay)
+                                 options.timestamp)
 
   for test_class in test_classes:
     runner.RegisterTest(test_class)
